@@ -19,17 +19,12 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: common.h,v 7.3 2002/01/05 09:14:27 a1kmm Exp $
+ *  $Id: common.h 33 2005-10-02 20:50:00Z knight $
  */
 
 #ifndef INCLUDED_common_h
 #define INCLUDED_common_h
 
-
-#ifndef NULL
-#define NULL 0
-#endif
-
 #ifdef TRUE
 #undef TRUE
 #endif
@@ -59,8 +54,4 @@
 
 #define IRCD_MAX(a, b)  ((a) > (b) ? (a) : (b))
 #define IRCD_MIN(a, b)  ((a) < (b) ? (a) : (b))
-
-/* Right out of the RFC */
-#define IRCD_BUFSIZE 512
-
 #endif /* INCLUDED_common_h */
