@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: motd.h,v 7.10 2002/05/24 23:34:07 androsyn Exp $
+ *  $Id: motd.h 33 2005-10-02 20:50:00Z knight $
  */
 
 #ifndef INCLUDED_motd_h
@@ -27,37 +27,40 @@
 #include "ircd_defs.h"   
 
 
-/* XXX really, should be mallocing this on the fly but... */
 #define MESSAGELINELEN 256
 
-typedef enum {
-  USER_MOTD,
-  USER_LINKS,
-  OPER_MOTD
-} MotdType;
-
 struct MessageFileLine
 {
-  char                    line[MESSAGELINELEN + 1];
-  struct MessageFileLine* next;
+  char line[MESSAGELINELEN + 1];
+  struct MessageFileLine *next;
 };
 
 typedef struct MessageFileLine MessageFileLine;
 
+typedef enum {
+  USER_MOTD,
+  USER_LINKS,
+  OPER_MOTD,
+  ISSUPPORT
+} MotdType;
+  
 struct MessageFile
 {
-  char             fileName[PATH_MAX + 1];
-  MotdType         motdType;
-  MessageFileLine* contentsOfFile;
-  char             lastChangedDate[MAX_DATE_STRING + 1];
+  MotdType motdType;
+  MessageFileLine *contentsOfFile;
+  char fileName[PATH_MAX + 1];
+  char lastChangedDate[MAX_DATE_STRING + 1];
 };
 
 typedef struct MessageFile MessageFile;
 
 struct Client;
 
-void InitMessageFile(MotdType, char *, struct MessageFile *);
-int SendMessageFile(struct Client *, struct MessageFile *);
-int ReadMessageFile(MessageFile *);
+extern void init_message_file(MotdType, const char *, struct MessageFile *);
+extern int send_message_file(struct Client *, struct MessageFile *);
+extern int read_message_file(MessageFile *);
+extern MessageFile *init_MessageLine(void);
+extern void addto_MessageLine(MessageFile *, const char *);
+extern void destroy_MessageLine(MessageFile *);
 
 #endif /* INCLUDED_motd_h */
