@@ -19,19 +19,27 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: numeric.h,v 7.31.2.1 2003/10/26 02:08:13 db Exp $
+ *  $Id: numeric.h 660 2006-06-09 18:51:22Z adx $
  */
 
 #ifndef INCLUDED_numeric_h
 #define INCLUDED_numeric_h
 
-#include "config.h"
+#define LOCALE_LENGTH 64  /* maximum length of locale name + 1 */
 
-/*
- * form_str - return a format string for a message number
+struct NumericInfo
+{
+  const char *name;     /* common name of the numeric */
+  const char *standard; /* standard numeric text      */
+  char *translated;     /* translated numeric text    */
+};
+
+/* form_str - return a format string for a message number
  * messages are defined below
  */
-extern const char* form_str(int);
+extern const char *form_str(int);
+extern void set_locale(const char *);
+extern const char *get_locale(void);
 
 /*
  * Reserve numerics 000-099 for server-client connections where the client
@@ -54,9 +62,8 @@ extern const char* form_str(int);
 #define RPL_MAP		     15		/* Undernet extension */
 #define RPL_MAPMORE	     16		/* Undernet extension */
 #define RPL_MAPEND	     17		/* Undernet extension */
-#define RPL_YOURID           20
 
-/*	RPL_YOURID	      42	IRCnet extension */
+#define RPL_YOURID	     42		/* IRCnet extension */
 /*      RPL_ATTEMPTINGJUNC    50           aircd extension */
 /*      RPL_ATTEMPTINGREROUTE 51           aircd extension */
 
@@ -71,6 +78,7 @@ extern const char* form_str(int);
 #define RPL_TRACEOPERATOR    204
 #define RPL_TRACEUSER        205
 #define RPL_TRACESERVER      206
+#define RPL_TRACECAPTURED    207
 #define RPL_TRACENEWTYPE     208
 #define RPL_TRACECLASS       209
 
@@ -116,9 +124,6 @@ extern const char* form_str(int);
 
 /*	RPL_RULES	     232	unreal */
 
-#define RPL_SERVLIST         234
-#define RPL_SERVLISTEND      235
-
 /*      RPL_STATSIAUTH       239           IRCnet extension */
 /*      RPL_STATSVLINE       240           IRCnet extension */
 /*	RPL_STATSXLINE	     240	austnet */
@@ -144,7 +149,6 @@ extern const char* form_str(int);
 #define RPL_ADMINLOC2        258
 #define RPL_ADMINEMAIL       259
 
-#define RPL_TRACELOG         261
 #define RPL_ENDOFTRACE       262
 #define RPL_LOAD2HI          263
 
@@ -159,9 +163,7 @@ extern const char* form_str(int);
 #define RPL_LOCALUSERS       265
 #define RPL_GLOBALUSERS      266
 
-#define RPL_VCHANEXIST       276
-#define RPL_VCHANLIST        277
-#define RPL_VCHANHELP        278
+#define RPL_WHOISSSL         275
 
 #define RPL_ACCEPTLIST	     281
 #define RPL_ENDOFACCEPT      282
@@ -193,8 +195,6 @@ extern const char* form_str(int);
 /*      RPL_END_CHANINFO     299           aircd */
 
 /* numeric_replies */
-
-#define RPL_NONE             300
 #define RPL_AWAY             301
 #define RPL_USERHOST         302
 #define RPL_ISON             303
@@ -205,7 +205,7 @@ extern const char* form_str(int);
 /*	RPL_WHOISREGNICK     307 	Numeric List: Dalnet */
 /*	RPL_SUSERHOST	     307	austnet */
 /*      RPL_NOTIFYACTION     308         aircd */
-/*	RPL_WHOISADMIN	     308	Numeric List: Dalnet */
+#define RPL_WHOISADMIN	     308	/* Numeric List: Dalnet */
 /*	RPL_RULESSTART	     308	unreal */
 /*      RPL_NICKTRACE        309         aircd */
 /*	RPL_WHOISSADMIN	     309	Numeric List: Dalnet */
@@ -266,7 +266,6 @@ extern const char* form_str(int);
 #define RPL_NAMREPLY         353
 #define RPL_ENDOFNAMES       366
 
-#define RPL_KILLDONE         361
 #define RPL_CLOSING          362
 #define RPL_CLOSEEND         363
 #define RPL_LINKS            364
@@ -292,8 +291,6 @@ extern const char* form_str(int);
 #define RPL_YOUREOPER        381
 #define RPL_REHASHING        382
 /*	RPL_YOURSERVICE	     383	   Numeric List: various */
-#define RPL_MYPORTIS         384
-#define RPL_NOTOPERANYMORE   385
 #define RPL_RSACHALLENGE     386
 
 /*	RPL_QLIST	     386	unreal */
@@ -306,6 +303,7 @@ extern const char* form_str(int);
 #define RPL_USERS            393
 #define RPL_ENDOFUSERS       394
 #define RPL_NOUSERS          395
+#define RPL_HOSTHIDDEN       396
 
 /*
  * Errors are in the range from 400-599 currently and are grouped by what
@@ -319,6 +317,7 @@ extern const char* form_str(int);
 #define ERR_WASNOSUCHNICK    406
 #define ERR_TOOMANYTARGETS   407
 #define ERR_NOORIGIN         409
+#define ERR_INVALIDCAPCMD    410
 
 #define ERR_NORECIPIENT      411
 #define ERR_NOTEXTTOSEND     412
@@ -328,7 +327,6 @@ extern const char* form_str(int);
 #define ERR_UNKNOWNCOMMAND   421
 #define ERR_NOMOTD           422
 #define ERR_NOADMININFO      423
-#define ERR_FILEERROR        424
 
 /* 	ERR_TOOMANYAWAY	     429	    Dalnet */
 
@@ -345,14 +343,11 @@ extern const char* form_str(int);
 #define ERR_UNAVAILRESOURCE  437
 #define ERR_NICKTOOFAST	     438	/* We did it first Undernet! ;) db */
 
-/*	ERR_SERVICESDOWN     440	Dalnet,unreal */
+#define ERR_SERVICESDOWN     440
 
 #define ERR_USERNOTINCHANNEL 441
 #define ERR_NOTONCHANNEL     442
 #define ERR_USERONCHANNEL    443
-#define ERR_NOLOGIN          444
-#define ERR_SUMMONDISABLED   445
-#define ERR_USERSDISABLED    446
 
 #define ERR_NOTREGISTERED    451
 
@@ -370,11 +365,8 @@ extern const char* form_str(int);
 
 #define ERR_NEEDMOREPARAMS   461
 #define ERR_ALREADYREGISTRED 462
-#define ERR_NOPERMFORHOST    463
 #define ERR_PASSWDMISMATCH   464
 #define ERR_YOUREBANNEDCREEP 465
-#define ERR_YOUWILLBEBANNED  466
-#define ERR_KEYSET           467
 /* 	ERR_ONLYSERVERSCANCHANGE 468	   Dalnet,unreal */
 /*	ERR_LINKSET	     469	unreal */
 /*	ERR_LINKCHANNEL	     470	unreal */
@@ -384,8 +376,7 @@ extern const char* form_str(int);
 #define ERR_INVITEONLYCHAN   473
 #define ERR_BANNEDFROMCHAN   474
 #define ERR_BADCHANNELKEY    475
-#define ERR_BADCHANMASK      476
-#define ERR_MODELESS         477        /* ircu numeric -db */
+/*      ERR_MODELESS         477           ircu numeric -db */
 #define ERR_BANLISTFULL      478        /* I stole the numeric from ircu -db */
 #define ERR_BADCHANNAME      479
 /* 	ERR_LINKFAIL	     479	unreal */
@@ -395,7 +386,6 @@ extern const char* form_str(int);
 #define ERR_CHANOPRIVSNEEDED 482
 #define ERR_CANTKILLSERVER   483
 #define ERR_RESTRICTED       484
-#define ERR_BANNEDNICK       485
 /*	ERR_DESYNC	     484	 Dalnet,PTlink */
 /*	ERR_ATTACKDENY	     484	 unreal */
 /*	ERR_RESTRICTED	     484	   IRCnet extension */
@@ -421,9 +411,6 @@ extern const char* form_str(int);
  * moved to 999
  */
 
-#define ERR_VCHANDISABLED    506
-#define ERR_ALREADYONVCHAN   507
-
 /*      ERR_NOTIFYFULL       512           aircd */
 /*	ERR_TOOMANYWATCH     512           Numeric List: Dalnet */
 /*      ERR_NEEDPONG	     512           Numeric List: Dalnet */
@@ -482,6 +469,22 @@ extern const char* form_str(int);
 #define ERR_KNOCKONCHAN      714
 #define ERR_KNOCKDISABLED    715
 
+#define RPL_TARGUMODEG       716
+#define RPL_TARGNOTIFY       717
+#define RPL_UMODEGMSG        718
+
+#define RPL_OMOTDSTART	     720
+#define RPL_OMOTD	     721
+#define RPL_ENDOFOMOTD	     722
+
+#define ERR_NOPRIVS	     723
+
+#define RPL_TESTMASK	     724
+#define RPL_TESTLINE	     725
+#define RPL_NOTESTLINE	     726
+#define RPL_ISCAPTURED	     727
+#define RPL_ISUNCAPTURED     728
+
 #define ERR_LAST_ERR_MSG     999
 
 #endif /* INCLUDED_numeric_h */
