@@ -19,12 +19,18 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- * $Id: stdinc.h,v 1.1 2002/05/24 23:39:13 androsyn Exp $
+ * $Id: stdinc.h 536 2006-03-23 09:59:02Z michael $
  *
  */
+
+#ifndef STDINC_H /* prevent multiple #includes */
+#define STDINC_H
  
-     
-#include "config.h" /* Gotta pull in the autoconf stuff */
+#ifndef IN_AUTOCONF
+#include "setup.h"
+#endif
+
+#include "defaults.h"
 
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
@@ -42,53 +48,86 @@
 # endif 
 #endif  
 
-
-#ifdef HAVE_STDDEF_H
-#include <stddef.h>
+#ifdef HAVE_STRTOK_R
+# define strtoken(x, y, z) strtok_r(y, z, x)
 #endif
 
+#include <sys/types.h>
 
+#ifdef HAVE_INTTYPES_H
+#include <inttypes.h>
+#else
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#endif
+#endif
+
+#ifdef HAVE_STDDEF_H
+# include <stddef.h>
+#else /* This is basically what stddef.h provides on most systems */
+# ifndef NULL
+#  define NULL ((void*)0)
+# endif
+# ifndef offsetof
+#  define offsetof(TYPE, MEMBER) ((size_t) &((TYPE *)0)->MEMBER)
+# endif
+#endif
+
+#ifdef HAVE_CRYPT_H
+#include <crypt.h>
+#endif
+
+#ifdef HAVE_LIBCRYPTO
+#include <openssl/ssl.h>
+#include <openssl/err.h>
+#endif
 
 #include <stdio.h>
 #include <assert.h>
-#include <stdio.h>
 #include <time.h>
 #include <fcntl.h>
-#include <netdb.h>
+
+#ifdef HAVE_LIBGEN_H
+#include <libgen.h>
+#endif
+
 #include <stdarg.h>
 #include <signal.h>
-#ifdef USE_GETTEXT
-#include <libintl.h>
-#endif
-#include <dirent.h>
 #include <ctype.h>
 
-#ifdef VMS
-#define _XOPEN_SOURCE 1
+#ifdef _WIN32
+#define PATH_MAX (MAX_PATH - 1)
+#define WIN32_LEAN_AND_MEAN
+#include <windows.h>
+#include <winsock.h>
+#else
+#include <dirent.h>
+#include <netdb.h>
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+#include <sys/time.h>
+#include <sys/file.h>
 #endif
+
 #include <limits.h>
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
-#include <sys/time.h>
-#include <sys/types.h>
-#include <sys/file.h>
 #ifdef HAVE_SYS_RESOURCE_H
 #include <sys/resource.h>
 #endif
 
-
-#include <sys/socket.h>
 #include <sys/stat.h>
+#ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
+#endif
 
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
 #endif
-#include <netinet/in.h>
-#include <arpa/inet.h>
 
 #ifdef HAVE_ERRNO_H
 #include <errno.h>
@@ -96,6 +135,11 @@
 extern int errno;
 #endif
 
-#ifdef VMS
-#include <sys/ioctl.h>
+#include "inet_misc.h"
+
+#ifdef _WIN32
+#undef strcasecmp
+#define strcasecmp stricmp
+#endif
+
 #endif
