@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: m_capab.c,v 1.31.2.1 2004/06/16 04:55:51 erik Exp $
+ *  $Id: m_capab.c 33 2005-10-02 20:50:00Z knight $
  */
 
 #include "stdinc.h"
@@ -32,12 +32,13 @@
 #include "parse.h"
 #include "modules.h"
 
-static void mr_capab(struct Client*, struct Client*, int, char**);
+static void mr_capab(struct Client *, struct Client *, int, char **);
 
 struct Message capab_msgtab = {
   "CAPAB", 0, 0, 0, 0, MFLG_SLOW | MFLG_UNREG, 0,
-  {mr_capab, m_ignore, m_ignore, m_ignore, m_ignore}
+  {mr_capab, m_ignore, m_ignore, m_ignore, m_ignore, m_ignore}
 };
+
 #ifndef STATIC_MODULES
 void
 _modinit(void)
@@ -51,7 +52,7 @@ _moddeinit(void)
   mod_del_cmd(&capab_msgtab);
 }
 
-const char *_version = "$Revision: 1.31.2.1 $";
+const char *_version = "$Revision: 33 $";
 #endif
 
 /*
@@ -60,13 +61,14 @@ const char *_version = "$Revision: 1.31.2.1 $";
  *      parv[1] = space-separated list of capabilities
  *
  */
-static void mr_capab(struct Client *client_p, struct Client *source_p,
-                    int parc, char *parv[])
+static void
+mr_capab(struct Client *client_p, struct Client *source_p,
+         int parc, char *parv[])
 {
-  struct Capability *cap;
   int i;
-  char* p;
-  char* s;
+  int cap;
+  char *p;
+  char *s;
 #ifdef HAVE_LIBCRYPTO
   struct EncCapability *ecap;
   unsigned int cipher = 0;
@@ -76,20 +78,20 @@ static void mr_capab(struct Client *client_p, struct Client *source_p,
   if (client_p->localClient == NULL)
     return;
 
-  if (client_p->localClient->caps)
+  if (client_p->localClient->caps && !(IsCapable(client_p, CAP_TS6)))
   {
-    exit_client(client_p, client_p, client_p, "CAPAB received twice");
+    exit_client(client_p, client_p, "CAPAB received twice");
     return;
   }
   else
-    client_p->localClient->caps |= CAP_CAP;
+    SetCapable(client_p, CAP_CAP);
 
-  for (i=1; i<parc; i++)
+  for (i = 1; i < parc; i++)
   {
     for (s = strtoken(&p, parv[i], " "); s; s = strtoken(&p, NULL, " "))
     {
 #ifdef HAVE_LIBCRYPTO
-      if ( (strncmp(s, "ENC:", 4) == 0) )
+      if ((strncmp(s, "ENC:", 4) == 0))
       {
         /* Skip the "ENC:" portion */
         s += 4;
@@ -99,7 +101,7 @@ static void mr_capab(struct Client *client_p, struct Client *source_p,
          */
         for (ecap = CipherTable; ecap->name; ecap++)
         {
-          if ( (!irccmp(ecap->name, s)) && (ecap->cap & CAP_ENC_MASK))
+          if ((irccmp(ecap->name, s) == 0) && (ecap->cap & CAP_ENC_MASK))
           {
             cipher = ecap->cap;
             break;
@@ -114,22 +116,15 @@ static void mr_capab(struct Client *client_p, struct Client *source_p,
         else
         {
           /* cipher is still zero; we didn't find a matching entry. */
-          exit_client(client_p, client_p, client_p,
-                      "Cipher selected is not available here.");
+          exit_client(client_p, client_p,
+	              "Cipher selected is not available here.");
           return;
         }
       }
       else /* normal capab */
 #endif
-        for (cap = captab; cap->name; cap++)
-        {
-          if (!irccmp(cap->name, s))
-          {
-            client_p->localClient->caps |= cap->cap;
-            break;
-          }
-        }
-    } /* for */
-  } /* for */
+        if ((cap = find_capability(s)) != 0)
+          SetCapable(client_p, cap);
+    }
+  }
 }
-
