@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: m_knock.c,v 1.52.2.1 2004/06/16 04:55:53 erik Exp $
+ *  $Id: m_knock.c 33 2005-10-02 20:50:00Z knight $
  */
 
 #include "stdinc.h"
@@ -30,16 +30,17 @@
 #include "client.h"
 #include "hash.h"
 #include "irc_string.h"
+#include "sprintf_irc.h"
 #include "ircd.h"
 #include "numeric.h"
 #include "send.h"
 #include "s_conf.h"
-#include "vchannel.h"
 #include "msg.h"
 #include "parse.h"
 #include "modules.h"
 #include "s_serv.h"
-
+#include "s_user.h"
+#include "common.h"
 
 static void m_knock(struct Client*, struct Client*, int, char**);
 static void ms_knock(struct Client *, struct Client *, int, char**);
@@ -48,22 +49,19 @@ static void me_knock(struct Client *, struct Client *, int, char**);
 static void parse_knock_local(struct Client *, struct Client *,
                               int, char **, char *);
 static void parse_knock_remote(struct Client *, struct Client *,
-                               int, char **, int);
+                                      int, char **, int);
 
 static void send_knock(struct Client *, struct Client *,
                        struct Channel *, char *, char *, int, int);
 
-static int is_banned_knock(struct Channel *, struct Client *, char *);
-static int check_banned_knock(struct Channel *, struct Client *,
-                              char *, char *);
-
 struct Message knock_msgtab = {
   "KNOCK", 0, 0, 2, 0, MFLG_SLOW, 0,
-  {m_unregistered, m_knock, ms_knock, me_knock, m_knock}
+  {m_unregistered, m_knock, ms_knock, me_knock, m_knock, m_ignore}
 };
+
 struct Message knockll_msgtab = {
   "KNOCKLL", 0, 0, 2, 0, MFLG_SLOW, 0,
-  {m_unregistered, m_ignore, m_knock, m_ignore, m_ignore}
+  {m_unregistered, m_ignore, m_knock, m_ignore, m_ignore, m_ignore}
 };
 
 #ifndef STATIC_MODULES
@@ -73,6 +71,8 @@ _modinit(void)
 {
   mod_add_cmd(&knock_msgtab);
   mod_add_cmd(&knockll_msgtab);
+  add_capability("KNOCK", CAP_KNOCK, 1);
+  add_isupport("KNOCK", NULL, -1);
 }
 
 void
@@ -80,18 +80,19 @@ _moddeinit(void)
 {
   mod_del_cmd(&knock_msgtab);
   mod_del_cmd(&knockll_msgtab);
+  delete_capability("KNOCK");
+  delete_isupport("KNOCK");
 }
 
-const char *_version = "$Revision: 1.52.2.1 $";
+const char *_version = "$Revision: 33 $";
 #endif
 
 /* m_knock
  *    parv[0] = sender prefix
  *    parv[1] = channel
- *    parv[2] = 'key' (for vchan)
  *
  *  The KNOCK command has the following syntax:
- *   :<sender> KNOCK <channel> <vchan id>
+ *   :<sender> KNOCK <channel>
  *
  *  If a user is not banned from the channel they can use the KNOCK
  *  command to have the server NOTICE the channel operators notifying
@@ -103,32 +104,29 @@ const char *_version = "$Revision: 1.52.2.1 $";
  *  This function is also used for LL servers forwarding knock requests they
  *  dont know about, for us to answer.
  */
-
 static void
-m_knock(struct Client *client_p, struct Client *source_p, int parc,
-	char *parv[])
+m_knock(struct Client *client_p, struct Client *source_p,
+        int parc, char *parv[])
 {
   char *sockhost = NULL;
-  
-  if((ConfigChannel.use_knock == 0) && MyClient(source_p))
-    {
-      sendto_one(source_p, form_str(ERR_KNOCKDISABLED),
-		 me.name, source_p->name);
-      return;
-    }
+
+  if ((ConfigChannel.use_knock == 0) && MyClient(source_p))
+  {
+    sendto_one(source_p, form_str(ERR_KNOCKDISABLED),
+               me.name, source_p->name);
+    return;
+  }
 
   /* a remote KNOCKLL request, check we're capable of handling it.. */
-  if(!MyConnect(source_p))
+  if (!MyConnect(source_p))
   {
-    if(!ServerInfo.hub || !IsCapable(client_p, CAP_LL) || parc < 3)
+    if (!ServerInfo.hub || !IsCapable(client_p, CAP_LL) || parc < 3)
       return;
     else
     {
-      /* set sockhost to parv[2], then shift the vchan id down if it
-       * exists.. done here to save messing in parse_knock_local()
-       */
+      /* set sockhost to parv[2] here to save messing in parse_knock_local() */
       sockhost = parv[2];
-      
+
       if(parc > 3)
       {
         parv[2] = parv[3];
@@ -141,7 +139,7 @@ m_knock(struct Client *client_p, struct Client *source_p, int parc,
     }
   }
     
-  if(IsClient(source_p))
+  if (IsClient(source_p))
     parse_knock_local(client_p, source_p, parc, parv, sockhost);
 }
 
@@ -149,14 +147,13 @@ m_knock(struct Client *client_p, struct Client *source_p, int parc,
  * ms_knock()
  *	parv[0] = sender prefix
  *	parv[1] = channel
- *	parv[2] = vchan id
  */
  
 static void
 ms_knock(struct Client *client_p, struct Client *source_p,
-		     int parc, char *parv[])
+	 int parc, char *parv[])
 {
-  if(IsClient(source_p))
+  if (IsClient(source_p))
     parse_knock_remote(client_p, source_p, parc, parv, 1);
 }
 
@@ -164,30 +161,27 @@ ms_knock(struct Client *client_p, struct Client *source_p,
  * me_knock()
  *	parv[0] = sender prefix
  *	parv[1] = channel
- *	parv[2] = vchan id
  */
  
 static void
 me_knock(struct Client *client_p, struct Client *source_p,
-		     int parc, char *parv[])
+	 int parc, char *parv[])
 {
-  if(IsClient(source_p))
+  if (IsClient(source_p))
     parse_knock_remote(client_p, source_p, parc, parv, 0);
 }
 
-/*
- * parse_knock_local()
+/* parse_knock_local()
  *
  * input        - pointer to physical struct client_p
  *              - pointer to source struct source_p
  *              - number of args
  *              - pointer to array of args
- *		- clients sockhost (if remote)
+ *		- clients sockhost
  * output       -
  * side effects - sets name to name of base channel
  *                or sends failure message to source_p
  */
-
 static void
 parse_knock_local(struct Client *client_p, struct Client *source_p,
                               int parc, char *parv[], char *sockhost)
@@ -197,116 +191,68 @@ parse_knock_local(struct Client *client_p, struct Client *source_p,
 
   struct Channel *chptr;
   char *p, *name, *key;
-#ifdef VCHANS
-  struct Channel *vchan_chptr;
-#endif
 
   name = parv[1];
   key = (parc > 2) ? parv[2] : NULL;
 
-  if((p = strchr(name,',')) != NULL)
+  if ((p = strchr(name, ',')) != NULL)
     *p = '\0';
 
-  if(!IsChannelName(name))
+  if (*name == '\0')
   {
-    sendto_one(source_p, form_str(ERR_NOSUCHCHANNEL),
-               me.name, parv[0], name);
+    sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
+               me.name, source_p->name, "KNOCK");
     return;
   }
 
-  if(!(chptr = hash_find_channel(name)))
+  if (!IsChanPrefix(*name))
   {
-    if(!ServerInfo.hub && uplink && IsCapable(uplink, CAP_LL))
+    sendto_one(source_p, form_str(ERR_NOSUCHCHANNEL),
+               me.name, source_p->name, name);
+    return;
+  }
+
+  if ((chptr = hash_find_channel(name)) == NULL)
+  {
+    if (!ServerInfo.hub && uplink && IsCapable(uplink, CAP_LL))
     {
       sendto_one(uplink, ":%s KNOCKLL %s %s %s",
-                 source_p->name, parv[1],
+                 ID_or_name(source_p, uplink), parv[1],
 		 IsIPSpoof(source_p) ? "255.255.255.255" :
-		 source_p->localClient->sockhost,
+		 source_p->sockhost,
 		 (parc > 2) ? parv[2] : "");
     }
     else
     {
-      sendto_one(source_p, form_str(ERR_NOSUCHCHANNEL), me.name, parv[0],
-                 name);
+      sendto_one(source_p, form_str(ERR_NOSUCHCHANNEL),
+                 me.name, source_p->name, name);
     }
 
     return;
   }
 
-#ifdef VCHANS
-  if (IsVchanTop(chptr))
+  /* Normal channel, just be sure they aren't on it */
+  if (IsMember(source_p, chptr))
   {
-    /* They specified a vchan basename */
-    if(on_sub_vchan(chptr,source_p))
-    {
-      sendto_one(source_p, form_str(ERR_KNOCKONCHAN),
-		 me.name, source_p->name, name);
-      return;
-    }
-    if (key && key[0] == '!')
-    {
-      /* Make "KNOCK #channel !" work like JOIN */
-      if (!key[1])
-      {
-	show_vchans(source_p, chptr, "knock");
-	return;
-      }
-
-      /* Find a matching vchan */
-      if ((vchan_chptr = find_vchan(chptr, key)))
-      {
-	chptr = vchan_chptr;
-      }
-      else
-      {
-	sendto_one(source_p, form_str(ERR_NOSUCHCHANNEL),
-		   me.name, parv[0], name);
-	return;
-      }
-    }
-    else
-    {
-      /* No key specified */
-      show_vchans(source_p, chptr, "knock");
-      return;
-    }
-  }
-  else if (IsVchan(chptr))
-  {
-    /* Don't allow KNOCK'ing a vchans 'real' name */
-    sendto_one(source_p, form_str(ERR_BADCHANNAME), me.name, parv[0],
-	       name);
+    sendto_one(source_p, form_str(ERR_KNOCKONCHAN),
+               me.name, source_p->name, name);
     return;
   }
-  else
-#endif
-  {
-    /* Normal channel, just be sure they aren't on it */
-    if (IsMember(source_p, chptr))
-    {
-      sendto_one(source_p, form_str(ERR_KNOCKONCHAN),
-		 me.name, source_p->name, name);
-      return;
-    }
-  }
 
-  if(!((chptr->mode.mode & MODE_INVITEONLY) ||
-       (*chptr->mode.key) ||
-       (chptr->mode.limit && chptr->users >= chptr->mode.limit )
-       ))
+  if (!((chptr->mode.mode & MODE_INVITEONLY) || (*chptr->mode.key) ||
+        (chptr->mode.limit && dlink_list_length(&chptr->members) >=
+         chptr->mode.limit)))
   {
     sendto_one(source_p, form_str(ERR_CHANOPEN),
-	       me.name, source_p->name, name);
+               me.name, source_p->name, name);
     return;
   }
 
   /* don't allow a knock if the user is banned, or the channel is secret */
-  if ((chptr->mode.mode & MODE_PRIVATE) ||
-      (sockhost && is_banned_knock(chptr, source_p, sockhost)) ||
-      (!sockhost && is_banned(chptr, source_p)))
+  if ((chptr->mode.mode & MODE_PRIVATE) || is_banned(chptr, source_p))
   {
-    sendto_one(source_p, form_str(ERR_CANNOTSENDTOCHAN), me.name, parv[0],
-	       name);
+    sendto_one(source_p, form_str(ERR_CANNOTSENDTOCHAN),
+               me.name, source_p->name, name);
     return;
   }
 
@@ -316,15 +262,16 @@ parse_knock_local(struct Client *client_p, struct Client *source_p,
    *
    * we only limit local requests..
    */
-  if(MyClient(source_p) &&
-    (source_p->localClient->last_knock + ConfigChannel.knock_delay) > CurrentTime)
+  if (MyClient(source_p) &&
+     (source_p->localClient->last_knock + ConfigChannel.knock_delay) >
+      CurrentTime)
   {
     sendto_one(source_p, form_str(ERR_TOOMANYKNOCK),
                me.name, source_p->name, parv[1], "user");
     return;
   }
-  else if((chptr->last_knock +
-         ConfigChannel.knock_delay_channel) > CurrentTime)
+  else if (chptr->last_knock +
+           ConfigChannel.knock_delay_channel > CurrentTime)
   {
     sendto_one(source_p, form_str(ERR_TOOMANYKNOCK),
                me.name, source_p->name, parv[1], "channel");
@@ -336,8 +283,7 @@ parse_knock_local(struct Client *client_p, struct Client *source_p,
              MyClient(source_p) ? 0 : 1, 1);
 }
 
-/*
- * parse_knock_remote
+/* parse_knock_remote()
  *
  * input	- pointer to client
  *		- pointer to source
@@ -349,160 +295,77 @@ parse_knock_local(struct Client *client_p, struct Client *source_p,
  */
 static void
 parse_knock_remote(struct Client *client_p, struct Client *source_p,
-		   int parc, char *parv[], int propagate)
+		   int parc, char *parv[], int prop)
 {
   struct Channel *chptr;
   char *p, *name, *key;
-#ifdef VCHANS
-  struct Channel *vchan_chptr;
-#endif
 
   name = parv[1];
-  key = (parc > 2) ? parv[2] : NULL;
+  key = parv[2];
 
-  if((p = strchr(name,',')) != NULL)
+  if ((p = strchr(name, ',')) != NULL)
     *p = '\0';
 
-  if(!IsChannelName(name) || !(chptr = hash_find_channel(name)))
+  if (!IsChanPrefix(*name) || (chptr = hash_find_channel(name)) == NULL)
     return;
 
-#ifdef VCHANS
-  if(IsVchanTop(chptr))
-  {
-    if(on_sub_vchan(chptr,source_p))
-      return;
-
-    if(key && (key[0] == '!') && (vchan_chptr = find_vchan(chptr, key)))
-      chptr = vchan_chptr;
-    else
-      return;
-  }
-  else if(IsVchan(chptr))
-    return;
-#endif
-
-  if(IsMember(source_p, chptr))
+  if (IsMember(source_p, chptr))
     return;
   
-  if(!((chptr->mode.mode & MODE_INVITEONLY) ||
-     (*chptr->mode.key) ||
-     (chptr->mode.limit && chptr->users >= chptr->mode.limit)))
+  if (!((chptr->mode.mode & MODE_INVITEONLY) || (*chptr->mode.key) ||
+        (chptr->mode.limit && dlink_list_length(&chptr->members) >=
+         chptr->mode.limit)))
     return;
 
-  if(chptr)
-    send_knock(client_p, source_p, chptr, name, key, 0, propagate);
-
-  return;
+  if (chptr)
+    send_knock(client_p, source_p, chptr, name, key, 0, prop);
 }
 
-/*
- * send_knock
+/* send_knock()
  *
  * input        - pointer to physical struct client_p
  *              - pointer to source struct source_p
  *              - pointer to channel struct chptr
  *              - pointer to base channel name
  * output       -
- * side effects - knock is sent locally (if enabled), propagated if specified
+ * side effects - knock is sent locally (if enabled) and propagated
  */
-
 static void
 send_knock(struct Client *client_p, struct Client *source_p,
 	   struct Channel *chptr, char *name, char *key, int llclient,
-	   int propagate)
+	   int prop)
 {
   chptr->last_knock = CurrentTime;
 
-  if(MyClient(source_p))
+  if (MyClient(source_p))
   {
     source_p->localClient->last_knock = CurrentTime;
 
     sendto_one(source_p, form_str(RPL_KNOCKDLVR),
                me.name, source_p->name, name);
   }
-  else if(llclient == 1)
+  else if (llclient == 1)
     sendto_one(source_p, form_str(RPL_KNOCKDLVR),
                me.name, source_p->name, name);
 
-  if(source_p->user != NULL)
-    {
-      if(ConfigChannel.use_knock)
-        sendto_channel_local(ONLY_CHANOPS_HALFOPS,
-  			     chptr, form_str(RPL_KNOCK),
+  if (IsClient(source_p))
+  {
+    if (ConfigChannel.use_knock)
+      sendto_channel_local(CHFL_CHANOP, NO,
+		     chptr, form_str(RPL_KNOCK),
 			     me.name, name, name,
 			     source_p->name, source_p->username,
 			     source_p->host);
-      
-      if(propagate)
-        sendto_server(client_p, source_p, chptr, CAP_KNOCK, NOCAPS, LL_ICLIENT,
-                    ":%s KNOCK %s %s",
-		    source_p->name, name, key ? key : "");
-    }
 
-  return;
-}
-
-/* is_banned_knock()
- * 
- * input	- pointer to channel
- *		- pointer to client
- *		- clients sockhost
- * output	- 
- * side effects - return check_banned_knock()
- */
-static int
-is_banned_knock(struct Channel *chptr, struct Client *who, char *sockhost)
-{
-  char src_host[NICKLEN + USERLEN + HOSTLEN + 6];
-  char src_iphost[NICKLEN + USERLEN + HOSTLEN + 6];
-
-  if(!IsPerson(who))
-    return 0;
-
-  ircsprintf(src_host,"%s!%s@%s", who->name, who->username, who->host);
-  ircsprintf(src_iphost,"%s!%s@%s", who->name, who->username, sockhost);
-
-  return (check_banned_knock(chptr, who, src_host, src_iphost));
-}
-
-/* check_banned_knock()
- *
- * input	- pointer to channel
- * 		- pointer to client
- *		- preformed nick!user@host
- *		- preformed nick!user@ip
- * output	- 
- * side effects - return CHFL_EXCEPTION, CHFL_BAN or 0
- */
-static int
-check_banned_knock(struct Channel *chptr, struct Client *who,
-		   char *s, char *s2)
-{
-  dlink_node *ban;
-  dlink_node *except;
-  struct Ban *actualBan = NULL;
-  struct Ban *actualExcept = NULL;
-
-  DLINK_FOREACH(ban, chptr->banlist.head)
-  {
-    actualBan = ban->data;
-
-    if (match(actualBan->banstr, s) || match(actualBan->banstr, s2))
-      break;
-    else
-      actualBan = NULL;
-  }
-
-  if ((actualBan != NULL) && ConfigChannel.use_except)
-  {
-    DLINK_FOREACH(except, chptr->exceptlist.head)
+    if (prop)
     {
-      actualExcept = except->data;
-
-      if (match(actualExcept->banstr, s) || match(actualExcept->banstr, s2))
-        return CHFL_EXCEPTION;
+      sendto_server(client_p, source_p, chptr, CAP_KNOCK|CAP_TS6, NOCAPS, LL_ICLIENT,
+                    ":%s KNOCK %s %s",
+                    ID(source_p), name, key != NULL ? key : "");
+      sendto_server(client_p, source_p, chptr, CAP_KNOCK, CAP_TS6, LL_ICLIENT,
+                    ":%s KNOCK %s %s",
+		    source_p->name, name, key != NULL ? key : "");
     }
   }
-
-  return ((actualBan ? CHFL_BAN : 0));
 }
+
