@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: m_pong.c,v 1.28.2.1 2004/06/16 04:55:53 erik Exp $
+ *  $Id: m_pong.c 503 2006-03-03 19:53:47Z michael $
  */
 
 #include "stdinc.h"
@@ -31,20 +31,17 @@
 #include "numeric.h"
 #include "s_conf.h"
 #include "send.h"
-#include "channel.h"
 #include "irc_string.h"
-#include "s_debug.h"
 #include "msg.h"
 #include "parse.h"
-#include "hash.h"
 #include "modules.h"
 
-static void mr_pong(struct Client*, struct Client*, int, char**);
-static void ms_pong(struct Client*, struct Client*, int, char**);
+static void mr_pong(struct Client *, struct Client *, int, char **);
+static void ms_pong(struct Client *, struct Client *, int, char **);
 
 struct Message pong_msgtab = {
   "PONG", 0, 0, 1, 0, MFLG_SLOW | MFLG_UNREG, 0,
-  {mr_pong, m_ignore, ms_pong, m_ignore, m_ignore}
+  {mr_pong, m_ignore, ms_pong, m_ignore, m_ignore, m_ignore}
 };
 
 #ifndef STATIC_MODULES
@@ -60,25 +57,25 @@ _moddeinit(void)
   mod_del_cmd(&pong_msgtab);
 }
 
-const char *_version = "$Revision: 1.28.2.1 $";
+const char *_version = "$Revision: 503 $";
 #endif
-static void ms_pong(struct Client *client_p,
-                   struct Client *source_p,
-                   int parc,
-                   char *parv[])
+
+static void
+ms_pong(struct Client *client_p, struct Client *source_p,
+        int parc, char *parv[])
 {
   struct Client *target_p;
-  char  *origin, *destination;
+  const char *origin, *destination;
 
   if (parc < 2 || *parv[1] == '\0')
-    {
-      sendto_one(source_p, form_str(ERR_NOORIGIN), me.name, parv[0]);
-      return;
-    }
+  {
+    sendto_one(source_p, form_str(ERR_NOORIGIN),
+               me.name, parv[0]);
+    return;
+  }
 
   origin = parv[1];
   destination = parv[2];
-  source_p->flags &= ~FLAGS_PINGSENT;
 
   /* Now attempt to route the PONG, comstud pointed out routable PING
    * is used for SPING.  routable PING should also probably be left in
@@ -86,8 +83,9 @@ static void ms_pong(struct Client *client_p,
    * That being the case, we will route, but only for registered clients (a
    * case can be made to allow them only from servers). -Shadowfax
    */
-  if (!EmptyString(destination) && !match(destination, me.name))
-    {
+  if (!EmptyString(destination) && !match(destination, me.name) &&
+      irccmp(destination, me.id))
+  {
       if ((target_p = find_client(destination)) ||
           (target_p = find_server(destination)))
         sendto_one(target_p,":%s PONG %s %s",
@@ -98,47 +96,41 @@ static void ms_pong(struct Client *client_p,
                      me.name, parv[0], destination);
           return;
         }
-    }
-
-#ifdef  DEBUGMODE
-  else
-    Debug((DEBUG_NOTICE, "PONG: %s %s", origin,
-           destination ? destination : "*"));
-#endif
-  return;
+  }
 }
 
 static void
 mr_pong(struct Client *client_p, struct Client *source_p,
-                    int parc, char *parv[])
+        int parc, char *parv[])
 {
+  assert(source_p == client_p);
+
   if (parc == 2 && *parv[1] != '\0')
+  {
+    if (ConfigFileEntry.ping_cookie && !source_p->localClient->registration)
     {
-      if(ConfigFileEntry.ping_cookie && source_p->user && source_p->name[0])
+      unsigned long incoming_ping = strtoul(parv[1], NULL, 10);
+
+      if (incoming_ping)
       {
-	unsigned long incoming_ping = strtoul(parv[1], (char **)NULL, 10);
-	if(incoming_ping)
-	{
-	  if(source_p->localClient->random_ping == incoming_ping)
-	  {
-		char buf[USERLEN+1];
-		strlcpy(buf, source_p->username, USERLEN + 1);
-		source_p->flags2 |= FLAGS2_PING_COOKIE;
-		register_local_user(client_p, source_p, source_p->name, buf);
-	  }
-	  else
-	  {
-		sendto_one(source_p, form_str(ERR_WRONGPONG), me.name,
-			   source_p->name, source_p->localClient->random_ping);
-		return;
-	  }
-	}
+        if (source_p->localClient->random_ping == incoming_ping)
+        {
+          char buf[USERLEN + 1];
+
+          strlcpy(buf, source_p->username, sizeof(buf));
+          SetPingCookie(source_p);
+          register_local_user(client_p, source_p, source_p->name, buf);
+        }
+        else
+        {
+          sendto_one(source_p, form_str(ERR_WRONGPONG), me.name,
+                     source_p->name, source_p->localClient->random_ping);
+          return;
+        }
       }
-     
     }
+  }
   else
     sendto_one(source_p, form_str(ERR_NOORIGIN), me.name, parv[0]);
-  
-  source_p->flags &= ~FLAGS_PINGSENT;
 }
 
