@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: m_post.c,v 1.14.2.1 2004/06/16 04:55:53 erik Exp $
+ *  $Id: m_post.c 33 2005-10-02 20:50:00Z knight $
  */
 
 #include "stdinc.h"
@@ -38,17 +38,17 @@ static void mr_dumb_proxy(struct Client*, struct Client*, int, char**);
 
 struct Message post_msgtab = {
   "POST", 0, 0, 0, 0, MFLG_SLOW | MFLG_UNREG, 0,
-  {mr_dumb_proxy, m_ignore, m_ignore, m_ignore, m_ignore}
+  {mr_dumb_proxy, m_ignore, m_ignore, m_ignore, m_ignore, m_ignore}
 };
 
 struct Message get_msgtab = {
   "GET", 0, 0, 0, 0, MFLG_SLOW | MFLG_UNREG, 0,
-  {mr_dumb_proxy, m_ignore, m_ignore, m_ignore, m_ignore}
+  {mr_dumb_proxy, m_ignore, m_ignore, m_ignore, m_ignore, m_ignore}
 };
 
 struct Message put_msgtab = {
   "PUT", 0, 0, 0, 0, MFLG_SLOW | MFLG_UNREG, 0,
-  {mr_dumb_proxy, m_ignore, m_ignore, m_ignore, m_ignore}
+  {mr_dumb_proxy, m_ignore, m_ignore, m_ignore, m_ignore, m_ignore}
 };
 
 
@@ -58,7 +58,8 @@ _modinit(void)
 {
   mod_add_cmd(&post_msgtab);
   mod_add_cmd(&get_msgtab);
-  mod_add_cmd(&put_msgtab);}
+  mod_add_cmd(&put_msgtab);
+}
 
 void
 _moddeinit(void)
@@ -68,22 +69,20 @@ _moddeinit(void)
   mod_del_cmd(&put_msgtab);
 }
 
-const char *_version = "$Revision: 1.14.2.1 $";
+const char *_version = "$Revision: 33 $";
 #endif
+
 /*
 ** mr_dumb_proxy
 **      parv[0] = sender prefix
 **      parv[1] = comment
 */
-static void mr_dumb_proxy(struct Client *client_p,
-                  struct Client *source_p,
-                  int parc,
-                  char *parv[])
+static void
+mr_dumb_proxy(struct Client *client_p, struct Client *source_p,
+              int parc, char *parv[])
 {
-  sendto_realops_flags(FLAGS_REJ, L_ALL,
+  sendto_realops_flags(UMODE_REJ, L_ALL,
                        "HTTP Proxy disconnected: [%s@%s]",
                        client_p->username, client_p->host);
-  exit_client(client_p, source_p, source_p, "Client Exit");
+  exit_client(source_p, source_p, "Client Exit");
 }
-
-
