@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: m_restart.c,v 1.23.4.1 2004/06/16 04:55:53 erik Exp $
+ *  $Id: m_restart.c 588 2006-05-08 13:22:59Z michael $
  */
 
 #include "stdinc.h"
@@ -27,21 +27,21 @@
 #include "client.h"
 #include "common.h"
 #include "irc_string.h"
+#include "sprintf_irc.h"
 #include "ircd.h"
 #include "numeric.h"
 #include "s_conf.h"
 #include "restart.h"
-#include "s_log.h"
 #include "send.h"
 #include "msg.h"
 #include "parse.h"
 #include "modules.h"
 
-static void mo_restart(struct Client *, struct Client *, int, char **);
+static void mo_restart(struct Client *, struct Client *, int, char *[]);
 
 struct Message restart_msgtab = {
   "RESTART", 0, 0, 0, 0, MFLG_SLOW, 0,
-  {m_unregistered, m_not_oper, m_ignore, m_ignore, mo_restart}
+  { m_unregistered, m_not_oper, m_ignore, m_ignore, mo_restart, m_ignore }
 };
 
 #ifndef STATIC_MODULES
@@ -57,68 +57,41 @@ _moddeinit(void)
   mod_del_cmd(&restart_msgtab);
 }
 
-const char *_version = "$Revision: 1.23.4.1 $";
+const char *_version = "$Revision: 588 $";
 #endif
+
 /*
  * mo_restart
  *
  */
-static void mo_restart(struct Client *client_p,
-                      struct Client *source_p,
-                      int parc,
-                      char *parv[])
+static void
+mo_restart(struct Client *client_p, struct Client *source_p,
+           int parc, char *parv[])
 {
-  char buf[BUFSIZE]; 
-  dlink_node *ptr;
-  struct Client *target_p;
-  
-  if (!MyClient(source_p) || !IsOper(source_p))
-    {
-      sendto_one(source_p, form_str(ERR_NOPRIVILEGES), me.name, parv[0]);
-      return;
-    }
+  char buf[IRCD_BUFSIZE]; 
 
-  if ( !IsOperDie(source_p) )
-    {
-      sendto_one(source_p,":%s NOTICE %s :You have no D flag", me.name, parv[0]);
-      return;
-    }
-
-  if (parc < 2)
+  if (!IsOperDie(source_p))
   {
-    sendto_one(source_p, ":%s NOTICE %s :Need server name /restart %s",
- 	       me.name, source_p->name, me.name);
+    sendto_one(source_p, form_str(ERR_NOPRIVS),
+               me.name, source_p->name, "restart");
     return;
   }
-  else
-  {
-    if (irccmp(parv[1], me.name))
-    {
-      sendto_one(source_p, ":%s NOTICE %s :Mismatch on /restart %s",
-		 me.name, source_p->name, me.name);
-      return;
-    }
-  }
-  
-  for(ptr = lclient_list.head; ptr; ptr = ptr->next)
-  {
-    target_p = ptr->data;
 
-    sendto_one(target_p,
-               ":%s NOTICE %s :Server Restarting. %s",
-	       me.name, target_p->name,
-	       get_client_name(source_p, HIDE_IP));
+  if (EmptyString(parv[1]))
+  {
+    sendto_one(source_p, ":%s NOTICE %s :Need server name /restart %s",
+               me.name, source_p->name, me.name);
+    return;
   }
 
-  for(ptr = serv_list.head; ptr; ptr = ptr->next)
+  if (irccmp(parv[1], me.name))
   {
-    target_p = ptr->data;
-
-    sendto_one(target_p, ":%s ERROR :Restart by %s",
-               me.name, get_client_name(source_p, HIDE_IP));
+    sendto_one(source_p, ":%s NOTICE %s :Mismatch on /restart %s",
+               me.name, source_p->name, me.name);
+    return;
   }
-  
-  ircsprintf(buf, "Server RESTART by %s", get_client_name(source_p, HIDE_IP));
-  restart(buf);
+
+  ircsprintf(buf, "received RESTART command from %s",
+             get_oper_name(source_p));
+  server_die(buf, YES);
 }
-
