@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: m_userhost.c,v 1.37.4.1 2004/06/16 04:55:55 erik Exp $
+ *  $Id: m_userhost.c 268 2005-11-14 11:02:39Z adx $
  */
 
 #include "stdinc.h"
@@ -30,18 +30,18 @@
 #include "s_serv.h"
 #include "send.h"
 #include "irc_string.h"
+#include "sprintf_irc.h"
 #include "msg.h"
 #include "parse.h"
 #include "modules.h"
 #include "s_conf.h"
 
-static char buf[BUFSIZE];
 
-static void m_userhost(struct Client*, struct Client*, int, char**);
+static void m_userhost(struct Client *, struct Client *, int, char *[]);
 
 struct Message userhost_msgtab = {
   "USERHOST", 0, 0, 1, 0, MFLG_SLOW, 0,
-  {m_unregistered, m_userhost, m_userhost, m_ignore, m_userhost}
+  {m_unregistered, m_userhost, m_userhost, m_ignore, m_userhost, m_ignore}
 };
 
 #ifndef STATIC_MODULES
@@ -57,19 +57,20 @@ _moddeinit(void)
   mod_del_cmd(&userhost_msgtab);
 }
 
-const char *_version = "$Revision: 1.37.4.1 $";
+const char *_version = "$Revision: 268 $";
 #endif
+
 /*
  * m_userhost added by Darren Reed 13/8/91 to aid clients and reduce
  * the need for complicated requests like WHOIS. It returns user/host
  * information only (no spurious AWAY labels or channels).
  */
-static void m_userhost(struct Client *client_p,
-                      struct Client *source_p,
-                      int parc,
-                      char *parv[])
+static void
+m_userhost(struct Client *client_p, struct Client *source_p,
+           int parc, char *parv[])
 {
   struct Client *target_p;
+  char buf[IRCD_BUFSIZE];
   char response[NICKLEN*2+USERLEN+HOSTLEN+30];
   char *t;
   int i, n;               /* loop counter */
@@ -79,72 +80,72 @@ static void m_userhost(struct Client *client_p,
   cur_len = ircsprintf(buf,form_str(RPL_USERHOST),me.name, parv[0], "");
   t = buf + cur_len;
 
-  for ( i = 0; i < 5; i++)
-    {
-      if (parv[i+1] == NULL)
-        break;
+  for (i = 0; i < 5; i++)
+  {
+    if (parv[i+1] == NULL)
+      break;
 
-      if ((target_p = find_person(parv[i+1])) != NULL)
-	{
+    if ((target_p = find_person(client_p, parv[i+1])) != NULL)
+    {
 	  /*
 	   * Show real IP for USERHOST on yourself.
 	   * This is needed for things like mIRC, which do a server-based
 	   * lookup (USERHOST) to figure out what the clients' local IP
 	   * is.  Useful for things like NAT, and dynamic dial-up users.
 	   */
-          /*
-           * If a lazyleaf relayed us this request, we don't know
-           * the clients real IP.
-           * So, if you're on a lazyleaf, and you send a userhost
-           * including your nick and the nick of someone not known to
-           * the leaf, you'll get your spoofed IP.  tough.
-           */
+      /*
+       * If a lazyleaf relayed us this request, we don't know
+       * the clients real IP.
+       * So, if you're on a lazyleaf, and you send a userhost
+       * including your nick and the nick of someone not known to
+       * the leaf, you'll get your spoofed IP.  tough.
+       */
 	  if (MyClient(target_p) && (target_p == source_p))
 	  {
             rl = ircsprintf(response, "%s%s=%c%s@%s ",
 			    target_p->name,
 			    IsOper(target_p) ? "*" : "",
-			    (target_p->user->away) ? '-' : '+',
+			    (target_p->away) ? '-' : '+',
 			    target_p->username,
-			    target_p->localClient->sockhost);
+			    target_p->sockhost);
 	  }
-          else
+      else
 	  {
             rl = ircsprintf(response, "%s%s=%c%s@%s ",
 			    target_p->name,
 			    IsOper(target_p) ? "*" : "",
-			    (target_p->user->away) ? '-' : '+',
+			    (target_p->away) ? '-' : '+',
 			    target_p->username,
 			    target_p->host);
 	  }
 
-	  if((rl + cur_len) < (BUFSIZE-10))
-	    {
-	      ircsprintf(t,"%s",response);
-	      t += rl;
-	      cur_len += rl;
-	    }
+	  if ((rl + cur_len) < (IRCD_BUFSIZE-10))
+      {
+        ircsprintf(t,"%s",response);
+        t += rl;
+        cur_len += rl;
+      }
 	  else
 	    break;
 	}
-      else if ( !ServerInfo.hub && uplink && IsCapable(uplink, CAP_LL) )
+    else if ( !ServerInfo.hub && uplink && IsCapable(uplink, CAP_LL) )
+    {
+      t = buf;
+      for ( n = 0; n < 5; n++ )
+      {
+        if( parv[n+1] )
         {
-          t = buf;
-          for( n = 0; n < 5; n++ )
-          {
-            if( parv[n+1] )
-            {
-              rl = ircsprintf(t, "%s ", parv[n+1]);
-              t += rl;
-            }
-            else
-              break;
-          }
-          /* Relay upstream, and let hub reply */
-          sendto_one(uplink, ":%s USERHOST %s", parv[0], buf );
-          return;
+          rl = ircsprintf(t, "%s ", parv[n+1]);
+          t += rl;
         }
+        else
+          break;
+      }
+      /* Relay upstream, and let hub reply */
+      sendto_one(uplink, ":%s USERHOST %s", parv[0], buf );
+      return;
     }
+  }
 
   sendto_one(source_p, "%s", buf);
 }
