@@ -19,10 +19,10 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: m_version.c,v 1.39.2.1 2004/06/16 04:55:55 erik Exp $
+ *  $Id: m_version.c 269 2005-11-14 19:39:09Z adx $
  */
 
-#include <stdinc.h>
+#include "stdinc.h"
 #include "handlers.h"
 #include "client.h"
 #include "ircd.h"
@@ -35,15 +35,29 @@
 #include "parse.h"
 #include "modules.h"
 
-static char* confopts(struct Client *source_p);
+static char *confopts(struct Client *);
+static void m_version(struct Client *, struct Client *, int, char *[]);
+static void ms_version(struct Client *, struct Client *, int, char *[]);
+static void mo_version(struct Client *, struct Client *, int, char *[]);
 
-static void m_version(struct Client*, struct Client*, int, char**);
-static void ms_version(struct Client*, struct Client*, int, char**);
-static void mo_version(struct Client*, struct Client*, int, char**);
+/* Option string. */
+static const char serveropts[] = {
+  ' ',
+  'T',
+  'S',
+#ifdef TS_CURRENT
+  '0' + TS_CURRENT,
+#endif
+/* ONLY do TS */
+/* ALWAYS do TS_WARNINGS */
+  'o',
+  'w',
+  '\0'
+};
 
 struct Message version_msgtab = {
   "VERSION", 0, 0, 0, 0, MFLG_SLOW, 0,
-  {m_unregistered, m_version, ms_version, m_ignore, mo_version}
+  { m_unregistered, m_version, ms_version, m_ignore, mo_version, m_ignore }
 };
 
 #ifndef STATIC_MODULES
@@ -59,40 +73,40 @@ _moddeinit(void)
   mod_del_cmd(&version_msgtab);
 }
 
-const char *_version = "$Revision: 1.39.2.1 $";
+const char *_version = "$Revision: 269 $";
 #endif
+
 /*
  * m_version - VERSION command handler
  *      parv[0] = sender prefix
  *      parv[1] = remote server
  */
-static void m_version(struct Client* client_p, struct Client* source_p,
-                      int parc, char* parv[])
+static void
+m_version(struct Client *client_p, struct Client *source_p,
+          int parc, char *parv[])
 {
-  static time_t last_used=0L;
+  static time_t last_used = 0;
 
-  if((last_used + ConfigFileEntry.pace_wait) > CurrentTime)
+  if ((last_used + ConfigFileEntry.pace_wait_simple) > CurrentTime)
   {
     /* safe enough to give this on a local connect only */
-    sendto_one(source_p,form_str(RPL_LOAD2HI),me.name,parv[0]);
+    sendto_one(source_p, form_str(RPL_LOAD2HI),
+               me.name, source_p->name);
     return;
   }
   else
-  {
     last_used = CurrentTime;
-  }
- 
-  if (!ConfigServerHide.disable_remote)
+
+  if (!ConfigFileEntry.disable_remote)
   {
     if (hunt_server(client_p, source_p, ":%s VERSION :%s",
                     1, parc, parv) != HUNTED_ISME)
       return;
   }
-  
-  sendto_one(source_p, form_str(RPL_VERSION), me.name,
-                parv[0], ircd_version, serno, debugmode,
-                me.name, confopts(source_p), serveropts);
-                
+
+  sendto_one(source_p, form_str(RPL_VERSION),
+             me.name, source_p->name, ircd_version, serno,
+             me.name, confopts(source_p), serveropts);
   show_isupport(source_p);
 }
 
@@ -101,20 +115,19 @@ static void m_version(struct Client* client_p, struct Client* source_p,
  *      parv[0] = sender prefix
  *      parv[1] = remote server
  */
-static void mo_version(struct Client* client_p, struct Client* source_p,
-                      int parc, char* parv[])
+static void
+mo_version(struct Client *client_p, struct Client *source_p,
+           int parc, char *parv[])
 {
   
   if (hunt_server(client_p, source_p, ":%s VERSION :%s", 
 		  1, parc, parv) != HUNTED_ISME)
     return;
-    
+
   sendto_one(source_p, form_str(RPL_VERSION), me.name, parv[0], ircd_version, 
-  	     serno, debugmode, me.name, confopts(source_p), serveropts);
-	       
+  	     serno, me.name, confopts(source_p), serveropts);
+
   show_isupport(source_p);
-  
-  return;
 }
 
 /*
@@ -122,80 +135,63 @@ static void mo_version(struct Client* client_p, struct Client* source_p,
  *      parv[0] = sender prefix
  *      parv[1] = remote server
  */
-static void ms_version(struct Client* client_p, struct Client* source_p,
-                      int parc, char* parv[])
+static void
+ms_version(struct Client *client_p, struct Client *source_p,
+           int parc, char *parv[])
 {
   if (hunt_server(client_p, source_p, ":%s VERSION :%s", 
                   1, parc, parv) == HUNTED_ISME)
   {
-    sendto_one(source_p, form_str(RPL_VERSION), me.name,
-               parv[0], ircd_version, serno, debugmode,
+    sendto_one(source_p, form_str(RPL_VERSION),
+               ID_or_name(&me, client_p),
+               ID_or_name(source_p, client_p),
+               ircd_version, serno,
                me.name, confopts(source_p), serveropts);
     show_isupport(source_p);
   }
-
-  return;
 }
 
 /* confopts()
+ *
  * input  - client pointer
  * output - ircd.conf option string
  * side effects - none
  */
-static char* confopts(struct Client *source_p)
+static char *
+confopts(struct Client *source_p)
 {
-  static char result[15];
-  char *p;
-  
-  result[0] = '\0';
-  p = result;
+  static char result[12];
+  char *p = result;
 
-#ifdef DEBUGMODE
-  *p++ = 'D';
-#endif
-
-  if(ConfigChannel.use_except)
+  if (ConfigChannel.use_except)
     *p++ = 'e';
-    
   if (ConfigFileEntry.glines)
-    *p++ = 'g';
     *p++ = 'G';
+  *p++ = 'g';
 
   /* might wanna hide this :P */
   if (ServerInfo.hub && 
-      (!ConfigServerHide.disable_remote || IsOper(source_p)) )
-    {
-      *p++ = 'H';
-    }
+      (!ConfigFileEntry.disable_remote || IsOper(source_p)))
+  {
+    *p++ = 'H';
+  }
 
-  if(ConfigChannel.use_invex)
+  if (ConfigChannel.use_invex)
     *p++ = 'I';
-
-  if(ConfigChannel.use_knock)
+  if (ConfigChannel.use_knock)
     *p++ = 'K';
-    
   *p++ = 'M';
 
-#ifdef CRYPT_OPER_PASSWORD
-  *p++ = 'p';
-#endif
-
-#ifdef IGNORE_BOGUS_TS
-  *p++ = 'T';
-#endif
-
+  if (ConfigFileEntry.ignore_bogus_ts)
+    *p++ = 'T';
 #ifdef USE_SYSLOG
   *p++ = 'Y';
 #endif
-
 #ifdef HAVE_LIBZ
   *p++ = 'Z';
 #endif
-
-#ifdef IPV6
   *p++ = '6';
-#endif
-  
+
   *p = '\0';
 
   return result;
