@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: m_wallops.c,v 1.30.2.1 2004/06/16 04:55:55 erik Exp $
+ *  $Id: m_wallops.c 33 2005-10-02 20:50:00Z knight $
  */
 
 #include "stdinc.h"
@@ -34,13 +34,14 @@
 #include "msg.h"
 #include "parse.h"
 #include "modules.h"
+#include "s_serv.h"
 
-static void ms_wallops(struct Client*, struct Client*, int, char**);
-static void mo_wallops(struct Client*, struct Client*, int, char**);
+static void ms_wallops(struct Client *, struct Client *, int, char **);
+static void mo_wallops(struct Client *, struct Client *, int, char **);
 
 struct Message wallops_msgtab = {
   "WALLOPS", 0, 0, 2, 0, MFLG_SLOW, 0,
-  {m_unregistered, m_not_oper, ms_wallops, m_ignore, mo_wallops}
+  {m_unregistered, m_not_oper, ms_wallops, m_ignore, mo_wallops, m_ignore}
 };
 
 #ifndef STATIC_MODULES
@@ -56,30 +57,32 @@ _moddeinit(void)
   mod_del_cmd(&wallops_msgtab);
 }
  
-const char *_version = "$Revision: 1.30.2.1 $";
+const char *_version = "$Revision: 33 $";
 #endif
+
 /*
  * mo_wallops (write to *all* opers currently online)
  *      parv[0] = sender prefix
  *      parv[1] = message text
  */
-static void mo_wallops(struct Client *client_p, struct Client *source_p,
-                      int parc, char *parv[])
+static void
+mo_wallops(struct Client *client_p, struct Client *source_p,
+	   int parc, char *parv[])
 { 
-  char* message;
+  const char *message = parv[1];
 
-  message = parv[1];
-  
   if (EmptyString(message))
-    {
-      sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
-                 me.name, parv[0], "WALLOPS");
-      return;
-    }
+  {
+    sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
+               me.name, source_p->name, "WALLOPS");
+    return;
+  }
 
-  sendto_wallops_flags(FLAGS_OPERWALL, source_p, "OPERWALL - %s", message);
-  sendto_server(NULL, source_p, NULL, NOCAPS, NOCAPS, LL_ICLIENT,
-                ":%s WALLOPS :%s", parv[0], message);
+  sendto_wallops_flags(UMODE_OPERWALL, source_p, "OPERWALL - %s", message);
+  sendto_server(NULL, source_p, NULL, CAP_TS6, NOCAPS, LL_ICLIENT,
+                ":%s WALLOPS :%s", ID(source_p), message);
+  sendto_server(NULL, source_p, NULL, NOCAPS, CAP_TS6, LL_ICLIENT,
+                ":%s WALLOPS :%s", source_p->name, message);
 }
 
 /*
@@ -87,26 +90,23 @@ static void mo_wallops(struct Client *client_p, struct Client *source_p,
  *      parv[0] = sender prefix
  *      parv[1] = message text
  */
-static void ms_wallops(struct Client *client_p, struct Client *source_p,
-                      int parc, char *parv[])
+static void
+ms_wallops(struct Client *client_p, struct Client *source_p,
+	   int parc, char *parv[])
 { 
-  char* message;
+  const char *message = parv[1];
 
-  message = parv[1];
-  
   if (EmptyString(message))
-    {
-      sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS),
-                 me.name, parv[0], "WALLOPS");
-      return;
-    }
+    return;
 
-  if(IsClient(source_p))
-    sendto_wallops_flags(FLAGS_OPERWALL, source_p, "OPERWALL - %s", message);
+  if (IsClient(source_p))
+    sendto_wallops_flags(UMODE_OPERWALL, source_p, "OPERWALL - %s", message);
   else
-    sendto_wallops_flags(FLAGS_WALLOP, source_p, "%s", message); 
+    sendto_wallops_flags(UMODE_WALLOP, source_p, "%s", message); 
 
-  sendto_server(client_p, source_p, NULL, NOCAPS, NOCAPS, LL_ICLIENT,
-                ":%s WALLOPS :%s", parv[0], message);
+  sendto_server(client_p, source_p, NULL, CAP_TS6, NOCAPS, LL_ICLIENT,
+                ":%s WALLOPS :%s", ID(source_p), message);
+  sendto_server(client_p, source_p, NULL, NOCAPS, CAP_TS6, LL_ICLIENT,
+                ":%s WALLOPS :%s", source_p->name, message);
 }
 
