@@ -15,21 +15,10 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *   $Id: io.c,v 1.28 2001/10/04 21:22:10 androsyn Exp $
+ *   $Id: io.c 33 2005-10-02 20:50:00Z knight $
  */
 
-#include "setup.h"
-
-#include <sys/types.h>
-#include <sys/socket.h>
-
-#include <assert.h>
-#include <errno.h>
-#include <string.h>
-#include <stdlib.h>
-#include <stdarg.h>
-#include <stdio.h>
-#include <unistd.h>
+#include "stdinc.h"
 
 #ifdef HAVE_LIBCRYPTO
 #include <openssl/evp.h>
@@ -45,7 +34,8 @@
 
 static int check_error(int, int, int);
 
-static char *fd_name(int fd)
+static const char *
+fd_name(int fd)
 {
   if (fd == CONTROL_R.fd)
     return "control read";
@@ -59,13 +49,13 @@ static char *fd_name(int fd)
     return "network";
 
   /* uh oh... */
-  return "unknown";
+  return("unknown");
 }
 
 #if defined( HAVE_LIBCRYPTO ) || defined( HAVE_LIBZ )
 static unsigned char tmp_buf[BUFLEN];
 #endif
-#if defined( HAVE_LIBZ ) && defined( HAVE_LIBZ )
+#ifdef HAVE_LIBZ
 static unsigned char tmp2_buf[BUFLEN];
 #endif
 
@@ -73,7 +63,8 @@ static unsigned char ctrl_buf[256] = "";
 static unsigned int  ctrl_len = 0;
 static unsigned int  ctrl_ofs = 0;
 
-void io_loop(int nfds)
+void
+io_loop(int nfds)
 {
   fd_set rfds;
   fd_set wfds;
@@ -114,7 +105,8 @@ void io_loop(int nfds)
   }
 }
 
-void send_data_blocking(int fd, unsigned char *data, int datalen)
+void
+send_data_blocking(int fd, unsigned char *data, int datalen)
 {
   int ret;
   fd_set wfds;
@@ -158,7 +150,8 @@ void send_data_blocking(int fd, unsigned char *data, int datalen)
  * used before CMD_INIT to pass contents of SendQ from ircd
  * to servlink.  This data must _not_ be encrypted/compressed.
  */
-void process_sendq(struct ctrl_command *cmd)
+void
+process_sendq(struct ctrl_command *cmd)
 {
   send_data_blocking(REMOTE_W.fd, cmd->data, cmd->datalen);
 }
@@ -170,13 +163,14 @@ void process_sendq(struct ctrl_command *cmd)
  * to servlink.  This data must be decrypted/decopmressed before
  * sending back to the ircd.
  */
-void process_recvq(struct ctrl_command *cmd)
+void
+process_recvq(struct ctrl_command *cmd)
 {
   int ret;
   unsigned char *buf;
-  int   blen;
+  unsigned int blen;
   unsigned char *data = cmd->data;
-  unsigned int   datalen = cmd->datalen;
+  unsigned int datalen = cmd->datalen;
 
   buf = data;
   blen = datalen;
@@ -200,26 +194,26 @@ void process_recvq(struct ctrl_command *cmd)
   if (in_state.zip)
   {
     /* decompress data */
-    in_state.zip_state.z_stream.next_in = buf;
-    in_state.zip_state.z_stream.avail_in = blen;
-    in_state.zip_state.z_stream.next_out = tmp2_buf;
-    in_state.zip_state.z_stream.avail_out = BUFLEN;
+    in_state.zip_state.stream.next_in = buf;
+    in_state.zip_state.stream.avail_in = blen;
+    in_state.zip_state.stream.next_out = tmp2_buf;
+    in_state.zip_state.stream.avail_out = BUFLEN;
 
     buf = tmp2_buf;
-    while(in_state.zip_state.z_stream.avail_in)
+    while (in_state.zip_state.stream.avail_in)
     {
-      if ((ret = inflate(&in_state.zip_state.z_stream,
+      if ((ret = inflate(&in_state.zip_state.stream,
                          Z_NO_FLUSH)) != Z_OK)
-        send_error("Inflate failed: %d", ret);
+        send_error("Inflate failed: %d (%s)", ret, zError(ret));
 
-      blen = BUFLEN - in_state.zip_state.z_stream.avail_out;
+      blen = BUFLEN - in_state.zip_state.stream.avail_out;
 
-      if (in_state.zip_state.z_stream.avail_in)
+      if (in_state.zip_state.stream.avail_in)
       {
         send_data_blocking(LOCAL_W.fd, buf, blen);
         blen = 0;
-        in_state.zip_state.z_stream.next_out = buf;
-        in_state.zip_state.z_stream.avail_out = BUFLEN;
+        in_state.zip_state.stream.next_out = buf;
+        in_state.zip_state.stream.avail_out = BUFLEN;
       }
     }
 
@@ -231,7 +225,8 @@ void process_recvq(struct ctrl_command *cmd)
   send_data_blocking(LOCAL_W.fd, buf, blen);
 }
 
-void send_zipstats(struct ctrl_command *unused)
+void
+send_zipstats(struct ctrl_command *unused)
 {
 #ifdef HAVE_LIBZ
   int i = 0;
@@ -245,30 +240,30 @@ void send_zipstats(struct ctrl_command *unused)
   ctrl_buf[i++] = RPL_ZIPSTATS;
   ctrl_buf[i++] = 0;
   ctrl_buf[i++] = 16;
-  ctrl_buf[i++] = ((in_state.zip_state.z_stream.total_out >> 24) & 0xFF);
-  ctrl_buf[i++] = ((in_state.zip_state.z_stream.total_out >> 16) & 0xFF);
-  ctrl_buf[i++] = ((in_state.zip_state.z_stream.total_out >>  8) & 0xFF);
-  ctrl_buf[i++] = ((in_state.zip_state.z_stream.total_out      ) & 0xFF);
+  ctrl_buf[i++] = ((in_state.zip_state.stream.total_out >> 24) & 0xFF);
+  ctrl_buf[i++] = ((in_state.zip_state.stream.total_out >> 16) & 0xFF);
+  ctrl_buf[i++] = ((in_state.zip_state.stream.total_out >>  8) & 0xFF);
+  ctrl_buf[i++] = ((in_state.zip_state.stream.total_out      ) & 0xFF);
 
-  ctrl_buf[i++] = ((in_state.zip_state.z_stream.total_in >> 24) & 0xFF);
-  ctrl_buf[i++] = ((in_state.zip_state.z_stream.total_in >> 16) & 0xFF);
-  ctrl_buf[i++] = ((in_state.zip_state.z_stream.total_in >>  8) & 0xFF);
-  ctrl_buf[i++] = ((in_state.zip_state.z_stream.total_in      ) & 0xFF);
+  ctrl_buf[i++] = ((in_state.zip_state.stream.total_in >> 24) & 0xFF);
+  ctrl_buf[i++] = ((in_state.zip_state.stream.total_in >> 16) & 0xFF);
+  ctrl_buf[i++] = ((in_state.zip_state.stream.total_in >>  8) & 0xFF);
+  ctrl_buf[i++] = ((in_state.zip_state.stream.total_in      ) & 0xFF);
 
-  ctrl_buf[i++] = ((out_state.zip_state.z_stream.total_in >> 24) & 0xFF);
-  ctrl_buf[i++] = ((out_state.zip_state.z_stream.total_in >> 16) & 0xFF);
-  ctrl_buf[i++] = ((out_state.zip_state.z_stream.total_in >>  8) & 0xFF);
-  ctrl_buf[i++] = ((out_state.zip_state.z_stream.total_in      ) & 0xFF);
+  ctrl_buf[i++] = ((out_state.zip_state.stream.total_in >> 24) & 0xFF);
+  ctrl_buf[i++] = ((out_state.zip_state.stream.total_in >> 16) & 0xFF);
+  ctrl_buf[i++] = ((out_state.zip_state.stream.total_in >>  8) & 0xFF);
+  ctrl_buf[i++] = ((out_state.zip_state.stream.total_in      ) & 0xFF);
 
-  ctrl_buf[i++] = ((out_state.zip_state.z_stream.total_out >> 24) & 0xFF);
-  ctrl_buf[i++] = ((out_state.zip_state.z_stream.total_out >> 16) & 0xFF);
-  ctrl_buf[i++] = ((out_state.zip_state.z_stream.total_out >>  8) & 0xFF);
-  ctrl_buf[i++] = ((out_state.zip_state.z_stream.total_out      ) & 0xFF);
+  ctrl_buf[i++] = ((out_state.zip_state.stream.total_out >> 24) & 0xFF);
+  ctrl_buf[i++] = ((out_state.zip_state.stream.total_out >> 16) & 0xFF);
+  ctrl_buf[i++] = ((out_state.zip_state.stream.total_out >>  8) & 0xFF);
+  ctrl_buf[i++] = ((out_state.zip_state.stream.total_out      ) & 0xFF);
 
-  in_state.zip_state.z_stream.total_in = 0;
-  in_state.zip_state.z_stream.total_out = 0;
-  out_state.zip_state.z_stream.total_in = 0;
-  out_state.zip_state.z_stream.total_out = 0;
+  in_state.zip_state.stream.total_in = 0;
+  in_state.zip_state.stream.total_out = 0;
+  out_state.zip_state.stream.total_in = 0;
+  out_state.zip_state.stream.total_out = 0;
   
   ret = check_error(write(CONTROL_W.fd, ctrl_buf, i), IO_WRITE, CONTROL_W.fd);
   if (ret < i)
@@ -291,11 +286,13 @@ void send_zipstats(struct ctrl_command *unused)
  *     flush the control fd sendq, then (blocking) send an
  *     error message over the control fd.
  */
-void send_error(char *message, ...)
+void
+send_error(const char *message, ...)
 {
   va_list args;
   static int sending_error = 0;
-  struct linger linger_opt = { 1, 30 }; /* wait 30 seconds */                     int len;
+  struct linger linger_opt = { 1, 30 }; /* wait 30 seconds */
+  int len;
 
   if (sending_error)
     exit(1); /* we did _try_ */
@@ -335,7 +332,8 @@ void send_error(char *message, ...)
 /* read_ctrl
  *      called when a command is waiting on the control pipe
  */
-void read_ctrl(void)
+void
+read_ctrl(void)
 {
   int ret;
   unsigned char tmp[2];
@@ -420,7 +418,8 @@ void read_ctrl(void)
   cmd.command = 0;
 }
 
-void write_ctrl(void)
+void
+write_ctrl(void)
 {
   int ret;
 
@@ -445,7 +444,8 @@ void write_ctrl(void)
     ctrl_ofs += ret;
 }
 
-void read_data(void)
+void
+read_data(void)
 {
   int ret, ret2;
   unsigned char *buf = out_state.buf;
@@ -465,27 +465,29 @@ void read_data(void)
 #ifdef HAVE_LIBZ
     if (out_state.zip)
     {
-      out_state.zip_state.z_stream.next_in = buf;
-      out_state.zip_state.z_stream.avail_in = ret;
+      out_state.zip_state.stream.next_in = buf;
+      out_state.zip_state.stream.avail_in = ret;
 
       buf = out_state.buf;
-#ifdef HAVE_LIB_CRYPTO
+      
+#ifdef HAVE_LIBCRYPTO
       if (out_state.crypt)
         buf = tmp2_buf;
 #endif
-      out_state.zip_state.z_stream.next_out = buf;
-      out_state.zip_state.z_stream.avail_out = BUFLEN;
-      if(!(ret2 = deflate(&out_state.zip_state.z_stream,
-                          Z_PARTIAL_FLUSH)) == Z_OK)
-        send_error("error compressing outgoing data - deflate returned %d",
-                   ret2);
 
-      if (!out_state.zip_state.z_stream.avail_out)
+      out_state.zip_state.stream.next_out = buf;
+      out_state.zip_state.stream.avail_out = BUFLEN;
+      if(!(ret2 = deflate(&out_state.zip_state.stream,
+                          Z_PARTIAL_FLUSH)) == Z_OK)
+        send_error("error compressing outgoing data - deflate returned %d (%s)",
+                   ret2, zError(ret2));
+
+      if (!out_state.zip_state.stream.avail_out)
         send_error("error compressing outgoing data - avail_out == 0");
-      if (out_state.zip_state.z_stream.avail_in)
+      if (out_state.zip_state.stream.avail_in)
         send_error("error compressing outgoing data - avail_in != 0");
 
-      blen = BUFLEN - out_state.zip_state.z_stream.avail_out;
+      blen = BUFLEN - out_state.zip_state.stream.avail_out;
     }
 #endif
 
@@ -523,7 +525,8 @@ void read_data(void)
 
 }
 
-void write_net(void)
+void
+write_net(void)
 {
   int ret;
 
@@ -549,7 +552,8 @@ void write_net(void)
     out_state.ofs += ret;
 }
 
-void read_net(void)
+void
+read_net(void)
 {
   int ret;
   int ret2;
@@ -589,20 +593,20 @@ void read_net(void)
     if (in_state.zip)
     {
       /* decompress data */
-      in_state.zip_state.z_stream.next_in = buf;
-      in_state.zip_state.z_stream.avail_in = ret;
-      in_state.zip_state.z_stream.next_out = in_state.buf;
-      in_state.zip_state.z_stream.avail_out = BUFLEN;
+      in_state.zip_state.stream.next_in = buf;
+      in_state.zip_state.stream.avail_in = ret;
+      in_state.zip_state.stream.next_out = in_state.buf;
+      in_state.zip_state.stream.avail_out = BUFLEN;
 
-      while (in_state.zip_state.z_stream.avail_in)
+      while (in_state.zip_state.stream.avail_in)
       {
-        if ((ret2 = inflate(&in_state.zip_state.z_stream,
+        if ((ret2 = inflate(&in_state.zip_state.stream,
                             Z_NO_FLUSH)) != Z_OK)
-          send_error("inflate failed: %d", ret2);
+          send_error("inflate failed: %d (%s)", ret2, zError(ret2));
 
-        blen = BUFLEN - in_state.zip_state.z_stream.avail_out;
+        blen = BUFLEN - in_state.zip_state.stream.avail_out;
 
-        if (in_state.zip_state.z_stream.avail_in)
+        if (in_state.zip_state.stream.avail_in)
         {
           if (blen)
           {
@@ -610,8 +614,8 @@ void read_net(void)
             blen = 0;
           }
 
-          in_state.zip_state.z_stream.next_out = in_state.buf;
-          in_state.zip_state.z_stream.avail_out = BUFLEN;
+          in_state.zip_state.stream.next_out = in_state.buf;
+          in_state.zip_state.stream.avail_out = BUFLEN;
         }
       }
 
@@ -640,7 +644,8 @@ void read_net(void)
   }
 }
 
-void write_data(void)
+void
+write_data(void)
 {
   int ret;
 
@@ -666,7 +671,8 @@ void write_data(void)
     in_state.ofs += ret;
 }
 
-int check_error(int ret, int io, int fd)
+int
+check_error(int ret, int io, int fd)
 {
   if (ret > 0) /* no error */
     return ret;
@@ -677,7 +683,8 @@ int check_error(int ret, int io, int fd)
   }
   
   /* ret == -1.. */
-  switch (errno) {
+  switch (errno)
+  {
     case EINPROGRESS:
     case EWOULDBLOCK:
 #if EAGAIN != EWOULDBLOCK
