@@ -1,41 +1,35 @@
-/************************************************************************
- *   IRC - Internet Relay Chat, src/ircd_signal.c
- *   Copyright (C) 1990 Jarkko Oikarinen and
- *                      University of Oulu, Computing Center
+/*
+ *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
+ *  ircd_signal.c: responsible for ircd's signal handling
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 1, or (at your option)
- *   any later version.
+ *  Copyright (C) 2002 by the past and present ircd coders, and others.
  *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
  *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  *
- * $Id: ircd_signal.c,v 7.14 2003/01/16 04:08:01 db Exp $
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ *  USA
+ *
+ *  $Id: ircd_signal.c 598 2006-05-13 09:08:47Z michael $
  */
 
 #include "stdinc.h"
+#include "common.h"
 #include "ircd_signal.h"
 #include "ircd.h"         /* dorehash */
-#include "restart.h"      /* server_reboot */
+#include "restart.h"      /* server_die */
 #include "s_log.h"
 #include "memory.h"
 #include "s_bsd.h"
-/*
- * dummy_handler - don't know if this is really needed but if alarm is still
- * being used we probably will
- */ 
-static void 
-dummy_handler(int sig)
-{
-  /* Empty */
-}
 
 /*
  * sigterm_handler - exit the server
@@ -43,14 +37,9 @@ dummy_handler(int sig)
 static void 
 sigterm_handler(int sig)  
 {
-  /* XXX we had a flush_connections() here - we should close all the
-   * connections and flush data. read server_reboot() for my explanation.
-   *     -- adrian
-   */
-  ilog(L_CRIT, "Server killed By SIGTERM");
-  exit(-1);
+  server_die("received signal SIGTERM", NO);
 }
-  
+
 /* 
  * sighup_handler - reread the server configuration
  */
@@ -89,48 +78,40 @@ sigchld_handler(int sig)
 static void 
 sigint_handler(int sig)
 {
-  static int restarting = 0;
-
-  if (server_state.foreground) 
-    {
-      ilog(L_WARN, "Server exiting on SIGINT");
-      exit(0);
-    }
-  else
-    {
-      ilog(L_WARN, "Server Restarting on SIGINT");
-      if (restarting == 0) 
-        {
-          restarting = 1;
-          server_reboot();
-        }
-    }
+  server_die("SIGINT received", !server_state.foreground);
 }
 
 /*
  * setup_signals - initialize signal handlers for server
  */
 void 
-setup_signals()
+setup_signals(void)
 {
   struct sigaction act;
 
   act.sa_flags = 0;
   act.sa_handler = SIG_IGN;
+
   sigemptyset(&act.sa_mask);
   sigaddset(&act.sa_mask, SIGPIPE);
   sigaddset(&act.sa_mask, SIGALRM);
+  sigaction(SIGALRM, &act, 0);
+#ifdef SIGTRAP
   sigaddset(&act.sa_mask, SIGTRAP);
+#endif
+#ifdef SIGXFSZ
+  sigaddset(&act.sa_mask, SIGXFSZ);
+  sigaction(SIGXFSZ, &act, 0);
+#endif
 
-# ifdef SIGWINCH
+#ifdef SIGWINCH
   sigaddset(&act.sa_mask, SIGWINCH);
   sigaction(SIGWINCH, &act, 0);
-# endif
+#endif
   sigaction(SIGPIPE, &act, 0);
+#ifdef SIGTRAP
   sigaction(SIGTRAP, &act, 0);
-
-  act.sa_handler = dummy_handler;
-  sigaction(SIGALRM, &act, 0);
+#endif
 
   act.sa_handler = sighup_handler;
   sigemptyset(&act.sa_mask);
@@ -153,5 +134,3 @@ setup_signals()
   sigaddset(&act.sa_mask, SIGCHLD);
   sigaction(SIGCHLD, &act, 0);
 }
-
-
