@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: packet.c,v 7.103 2003/02/16 22:54:37 db Exp $
+ *  $Id: packet.c 428 2006-02-11 12:21:51Z michael $
  */
 #include "stdinc.h"
 #include "tools.h"
@@ -37,10 +37,84 @@
 #include "memory.h"
 #include "hook.h"
 #include "send.h"
+#include "irc_getnameinfo.h"
 
-static char               readBuf[READBUF_SIZE];
-static void client_dopacket(struct Client *client_p, char *buffer, size_t length);
+#define READBUF_SIZE 16384
 
+struct Callback *iorecv_cb = NULL;
+struct Callback *iorecvctrl_cb = NULL;
+
+static char readBuf[READBUF_SIZE];
+static void client_dopacket(struct Client *, char *, size_t);
+
+/* extract_one_line()
+ *
+ * inputs       - pointer to a dbuf queue
+ *              - pointer to buffer to copy data to
+ * output       - length of <buffer>
+ * side effects - one line is copied and removed from the dbuf
+ */
+static int
+extract_one_line(struct dbuf_queue *qptr, char *buffer)
+{
+  struct dbuf_block *block;
+  int line_bytes = 0, empty_bytes = 0, phase = 0;
+  unsigned int idx;
+
+  char c;
+  dlink_node *ptr;
+
+  /*
+   * Phase 0: "empty" characters before the line
+   * Phase 1: copying the line
+   * Phase 2: "empty" characters after the line
+   *          (delete them as well and free some space in the dbuf)
+   *
+   * Empty characters are CR, LF and space (but, of course, not
+   * in the middle of a line). We try to remove as much of them as we can,
+   * since they simply eat server memory.
+   *
+   * --adx
+   */
+  DLINK_FOREACH(ptr, qptr->blocks.head)
+  {
+    block = ptr->data;
+
+    for (idx = 0; idx < block->size; idx++)
+    {
+      c = block->data[idx];
+      if (IsEol(c) || (c == ' ' && phase != 1))
+      {
+        empty_bytes++;
+        if (phase == 1)
+          phase = 2;
+      }
+      else switch (phase)
+      {
+        case 0: phase = 1;
+        case 1: if (line_bytes++ < IRCD_BUFSIZE - 2)
+                  *buffer++ = c;
+                break;
+        case 2: *buffer = '\0';
+                dbuf_delete(qptr, line_bytes + empty_bytes);
+                return IRCD_MIN(line_bytes, IRCD_BUFSIZE - 2);
+      }
+    }
+  }
+
+  /*
+   * Now, if we haven't reached phase 2, ignore all line bytes
+   * that we have read, since this is a partial line case.
+   */
+  if (phase != 2)
+    line_bytes = 0;
+  else
+    *buffer = '\0';
+
+  /* Remove what is now unnecessary */
+  dbuf_delete(qptr, line_bytes + empty_bytes);
+  return IRCD_MIN(line_bytes, IRCD_BUFSIZE - 2);
+}
 
 /*
  * parse_client_queued - parse client queued messages
@@ -52,73 +126,48 @@ parse_client_queued(struct Client *client_p)
   int checkflood = 1;
   struct LocalUser *lclient_p = client_p->localClient;
 
-  if(IsUnknown(client_p))
+  if (IsUnknown(client_p))
   {
     int i = 0;
 
     for(;;)
     {
-      if (IsClosing(client_p))
-	return;
-      if (client_p->localClient == NULL)
+      if (IsDefunct(client_p))
 	return;
 
       /* rate unknown clients at MAX_FLOOD per loop */
-      if(i >= MAX_FLOOD)
+      if (i >= MAX_FLOOD)
         break;
 
-	dolen = linebuf_get(&client_p->localClient->buf_recvq, readBuf,
-			    READBUF_SIZE, LINEBUF_COMPLETE, LINEBUF_PARSED);
+      dolen = extract_one_line(&lclient_p->buf_recvq, readBuf);
+      if (dolen == 0)
+	break;
 
-	if(dolen <= 0)
-	  break;
-                          
-      if(!IsDefunct(client_p))
-      {
-        client_dopacket(client_p, readBuf, dolen);
-        i++;
+      client_dopacket(client_p, readBuf, dolen);
+      i++;
 
-        /* if they've dropped out of the unknown state, break and move
-         * to the parsing for their appropriate status.  --fl
-         */
-        if(!IsUnknown(client_p))
-          break;
-      }
-      else if(MyConnect(client_p))
-      {
-        linebuf_donebuf(&client_p->localClient->buf_recvq);
-        linebuf_donebuf(&client_p->localClient->buf_sendq);
-        return;
-      }
+      /* if they've dropped out of the unknown state, break and move
+       * to the parsing for their appropriate status.  --fl
+       */
+      if(!IsUnknown(client_p))
+        break;
     }
   }
 
   if (IsServer(client_p) || IsConnecting(client_p) || IsHandshake(client_p))
   {
-    if(IsDefunct(client_p))
-      return;
-    if(client_p->localClient == NULL)
-      return;
-    
-    while ((dolen = linebuf_get(&client_p->localClient->buf_recvq,
-                              readBuf, READBUF_SIZE, LINEBUF_COMPLETE,
-                              LINEBUF_PARSED)) > 0)
+    while (1)
     {
-      if (!IsDefunct(client_p))
-        client_dopacket(client_p, readBuf, dolen);
-      else if(MyConnect(client_p))
-      {
-        linebuf_donebuf(&client_p->localClient->buf_recvq);
-        linebuf_donebuf(&client_p->localClient->buf_sendq);
+      if (IsDefunct(client_p))
         return;
-      }
-      if (client_p->localClient == NULL)
-	return; 
+      if ((dolen = extract_one_line(&lclient_p->buf_recvq,
+                                    readBuf)) == 0)
+        break;
+      client_dopacket(client_p, readBuf, dolen);
     }
-  } 
-  else if(IsClient(client_p))
+  }
+  else if (IsClient(client_p))
   {
-
     if (ConfigFileEntry.no_oper_flood && (IsOper(client_p) || IsCanFlood(client_p)))
     {
       if (ConfigFileEntry.true_no_oper_flood)
@@ -132,7 +181,7 @@ parse_client_queued(struct Client *client_p)
      * messages in this loop, we simply drop out of the loop prematurely.
      *   -- adrian
      */
-    for(;;)
+    for (;;)
     {
       if (IsDefunct(client_p))
 	break;
@@ -150,7 +199,7 @@ parse_client_queued(struct Client *client_p)
        * as sent_parsed will always hover around the allow_read limit
        * and no 'bursts' will be permitted.
        */
-      if(checkflood > 0)
+      if (checkflood > 0)
       {
         if(lclient_p->sent_parsed >= lclient_p->allow_read)
           break;
@@ -159,18 +208,14 @@ parse_client_queued(struct Client *client_p)
       /* allow opers 4 times the amount of messages as users. why 4?
        * why not. :) --fl_
        */
-      else if(lclient_p->sent_parsed >= (4 * lclient_p->allow_read) && checkflood != -1)
+      else if (lclient_p->sent_parsed >= (4 * lclient_p->allow_read) &&
+               checkflood != -1)
         break;
-       
-      if(client_p->localClient == NULL)
-	break;
 
-      dolen = linebuf_get(&client_p->localClient->buf_recvq, readBuf,
-                          READBUF_SIZE, LINEBUF_COMPLETE, LINEBUF_PARSED);
-			 
-      if (!dolen)
+      dolen = extract_one_line(&lclient_p->buf_recvq, readBuf);
+      if (dolen == 0)
         break;
-       
+
       client_dopacket(client_p, readBuf, dolen);
       lclient_p->sent_parsed++;
     }
@@ -194,7 +239,7 @@ flood_endgrace(struct Client *client_p)
    */
   client_p->localClient->sent_parsed = 0;
 }
-	    
+
 /*
  * flood_recalc
  *
@@ -202,29 +247,22 @@ flood_endgrace(struct Client *client_p)
  * once a second on any given client. We then attempt to flush some data.
  */
 void
-flood_recalc(int fd, void *data)
+flood_recalc(fde_t *fd, void *data)
 {
   struct Client *client_p = data;
   struct LocalUser *lclient_p = client_p->localClient;
  
-  /* This can happen in the event that the client detached. */
-  if (!lclient_p)
-    return;
-
   /* allow a bursting client their allocation per second, allow
    * a client whos flooding an extra 2 per second
    */
-  if(IsFloodDone(client_p))
+  if (IsFloodDone(client_p))
     lclient_p->sent_parsed -= 2;
   else
     lclient_p->sent_parsed = 0;
   
-  if(lclient_p->sent_parsed < 0)
+  if (lclient_p->sent_parsed < 0)
     lclient_p->sent_parsed = 0;
   
-  if(--lclient_p->actually_read < 0)
-    lclient_p->actually_read = 0;
-
   parse_client_queued(client_p);
   
   /* And now, try flushing .. */
@@ -240,7 +278,7 @@ flood_recalc(int fd, void *data)
  *                    link and process it.
  */
 void
-read_ctrl_packet(int fd, void *data)
+read_ctrl_packet(fde_t *fd, void *data)
 {
   struct Client *server = data;
   struct LocalUser *lserver = server->localClient;
@@ -249,19 +287,13 @@ read_ctrl_packet(int fd, void *data)
   unsigned char tmp[2];
   unsigned char *len = tmp;
   struct SlinkRplDef *replydef;
-#ifndef NDEBUG
-  struct hook_io_data hdata;
-#endif
- 
- 
+
   assert(lserver != NULL);
     
   reply = &lserver->slinkrpl;
 
-  if(IsDefunct(server))
-  {
+  if (IsDefunct(server))
     return;
-  }
 
   if (!reply->command)
   {
@@ -269,11 +301,11 @@ read_ctrl_packet(int fd, void *data)
     reply->readdata = 0;
     reply->data = NULL;
 
-    length = recv(fd, tmp, 1, 0);
+    length = recv(fd->fd, tmp, 1, 0);
 
     if (length <= 0)
     {
-      if((length == -1) && ignoreErrno(errno))
+      if ((length == -1) && ignoreErrno(errno))
         goto nodata;
       dead_link_on_read(server, length);
       return;
@@ -281,9 +313,9 @@ read_ctrl_packet(int fd, void *data)
     reply->command = tmp[0];
   }
 
-  for(replydef = slinkrpltab; replydef->handler; replydef++)
+  for (replydef = slinkrpltab; replydef->handler; replydef++)
   {
-    if (replydef->replyid == reply->command)
+    if (replydef->replyid == (unsigned int)reply->command)
       break;
   }
 
@@ -294,10 +326,10 @@ read_ctrl_packet(int fd, void *data)
   if ((replydef->flags & SLINKRPL_FLAG_DATA) && (reply->gotdatalen < 2))
   {
     /* we need a datalen u16 which we don't have yet... */
-    length = recv(fd, len, (2 - reply->gotdatalen), 0);
+    length = recv(fd->fd, len, (2 - reply->gotdatalen), 0);
     if (length <= 0)
     {
-      if((length == -1) && ignoreErrno(errno))
+      if ((length == -1) && ignoreErrno(errno))
         goto nodata;
       dead_link_on_read(server, length);
       return;
@@ -324,11 +356,11 @@ read_ctrl_packet(int fd, void *data)
 
   if (reply->readdata < reply->datalen) /* try to get any remaining data */
   {
-    length = recv(fd, (reply->data + reply->readdata),
+    length = recv(fd->fd, (reply->data + reply->readdata),
                   (reply->datalen - reply->readdata), 0);
     if (length <= 0)
     {
-      if((length == -1) && ignoreErrno(errno))
+      if ((length == -1) && ignoreErrno(errno))
         goto nodata;
       dead_link_on_read(server, length);
       return;
@@ -339,13 +371,8 @@ read_ctrl_packet(int fd, void *data)
       return; /* wait for more data */
   }
 
-#ifndef NDEBUG
-  hdata.connection = server;
-  hdata.len = reply->command;
-  hdata.data = NULL;
-  hook_call_event("iorecvctrl", &hdata);
-#endif
-  
+  execute_callback(iorecvctrl_cb, server, reply->command);
+
   /* we now have the command and any data, pass it off to the handler */
   (*replydef->handler)(reply->command, reply->datalen, reply->data, server);
 
@@ -359,125 +386,125 @@ read_ctrl_packet(int fd, void *data)
 
 nodata:
   /* If we get here, we need to register for another COMM_SELECT_READ */
-  comm_setselect(fd, FDLIST_SERVER, COMM_SELECT_READ,
-                 read_ctrl_packet, server, 0);
+  comm_setselect(fd, COMM_SELECT_READ, read_ctrl_packet, server, 0);
 }
-  
+
+/*
+ * iorecv_default - append a packet to the recvq dbuf
+ */
+void *
+iorecv_default(va_list args)
+{
+  struct Client *client_p = va_arg(args, struct Client *);
+  int length = va_arg(args, int);
+  char *buf = va_arg(args, char *);
+
+  dbuf_put(&client_p->localClient->buf_recvq, buf, length);
+  return NULL;
+}
+
 /*
  * read_packet - Read a 'packet' of data from a connection and process it.
  */
 void
-read_packet(int fd, void *data)
+read_packet(fde_t *fd, void *data)
 {
   struct Client *client_p = data;
-  struct LocalUser *lclient_p = client_p->localClient;
   int length = 0;
-  int lbuf_len;
-  int fd_r; 
-  int binary = 0;
-#ifndef NDEBUG
-  struct hook_io_data hdata;
-#endif
-  if(IsDefunct(client_p))
-    return;
-  
-  assert(lclient_p != NULL);
-  fd_r = client_p->localClient->fd;
 
-#ifndef HAVE_SOCKETPAIR
-  if (HasServlink(client_p))
-  {
-    assert(client_p->localClient->fd_r > -1);
-    fd_r = client_p->localClient->fd_r;
-  }
-#endif
+  if (IsDefunct(client_p))
+    return;
 
   /*
    * Read some data. We *used to* do anti-flood protection here, but
    * I personally think it makes the code too hairy to make sane.
    *     -- adrian
    */
-  length = recv(fd_r, readBuf, READBUF_SIZE, 0);
-
-  if (length <= 0)
-  {
-    if((length == -1) && ignoreErrno(errno))
+  do {
+#ifdef HAVE_LIBCRYPTO
+    if (fd->ssl)
     {
-      comm_setselect(fd_r, FDLIST_IDLECLIENT, COMM_SELECT_READ,
-      		read_packet, client_p, 0);
-      return;
-    }  	
-    dead_link_on_read(client_p, length);
-    return;
-  }
+      length = SSL_read(fd->ssl, readBuf, READBUF_SIZE);
 
-#ifndef NDEBUG
-  hdata.connection = client_p;
-  hdata.data = readBuf;
-  hdata.len = length;
-  hook_call_event("iorecv", &hdata);
-#endif
-  
-  if (client_p->lasttime < CurrentTime)
-    client_p->lasttime = CurrentTime;
-  if (client_p->lasttime > client_p->since)
-    client_p->since = CurrentTime;
-  ClearPingSent(client_p);
-
-  /*
-   * Before we even think of parsing what we just read, stick
-   * it on the end of the receive queue and do it when its
-   * turn comes around.
-   */
-  if (IsHandshake(client_p) || IsUnknown(client_p))
-    binary = 1;
-
-  lbuf_len = linebuf_parse(&client_p->localClient->buf_recvq,
-                           readBuf, length, binary);
-
-  lclient_p->actually_read += lbuf_len;
-  
-  /* Attempt to parse what we have */
-
-  parse_client_queued(client_p);
-
-  /* Check to make sure we're not flooding */
-  if (IsPerson(client_p) &&
-      (linebuf_alloclen(&client_p->localClient->buf_recvq) >
-       ConfigFileEntry.client_flood))
-  {
-    if (!(ConfigFileEntry.no_oper_flood && IsOper(client_p)))
-    {
-      exit_client(client_p, client_p, client_p, "Excess Flood");
-      return;
-    }
-  }
-
-  /* server fd may have changed */
-  fd_r = client_p->localClient->fd;
-#ifndef HAVE_SOCKETPAIR
-  if (HasServlink(client_p))
-  {
-    assert(client_p->localClient->fd_r > -1);
-    fd_r = client_p->localClient->fd_r;
-  }
-#endif
-
-  
-  if (!IsDefunct(client_p))
-  {
-    /* If we get here, we need to register for another COMM_SELECT_READ */
-    if (PARSE_AS_SERVER(client_p))
-    {
-      comm_setselect(fd_r, FDLIST_SERVER, COMM_SELECT_READ,
-		     read_packet, client_p, 0);
+      /* translate openssl error codes, sigh */
+      if (length < 0)
+        switch (SSL_get_error(fd->ssl, length))
+	{
+          case SSL_ERROR_WANT_WRITE:
+            fd->flags.pending_read = 1;
+	    SetSendqBlocked(client_p);
+	    comm_setselect(fd, COMM_SELECT_WRITE, (PF *) sendq_unblocked,
+	                   client_p, 0);
+	    return;
+	  case SSL_ERROR_WANT_READ:
+	    errno = EWOULDBLOCK;
+          case SSL_ERROR_SYSCALL:
+	    break;
+          case SSL_ERROR_SSL:
+            if (errno == EAGAIN)
+              break;
+          default:
+	    length = errno = 0;
+	}
     }
     else
+#endif
     {
-      comm_setselect(fd_r, FDLIST_IDLECLIENT, COMM_SELECT_READ,
-		     read_packet, client_p, 0);
+      length = recv(fd->fd, readBuf, READBUF_SIZE, 0);
+#ifdef _WIN32
+      if (length < 0)
+        errno = WSAGetLastError();
+#endif
+    }
+
+    if (length <= 0)
+    {
+      /*
+       * If true, then we can recover from this error.  Just jump out of
+       * the loop and re-register a new io-request.
+       */
+      if (length < 0 && ignoreErrno(errno))
+        break;
+
+      dead_link_on_read(client_p, length);
+      return;
+    }
+
+    execute_callback(iorecv_cb, client_p, length, readBuf);
+
+    if (client_p->lasttime < CurrentTime)
+      client_p->lasttime = CurrentTime;
+    if (client_p->lasttime > client_p->since)
+      client_p->since = CurrentTime;
+    ClearPingSent(client_p);
+
+    /* Attempt to parse what we have */
+    parse_client_queued(client_p);
+
+    if (IsDefunct(client_p))
+      return;
+
+    /* Check to make sure we're not flooding */
+    /* TBD - ConfigFileEntry.client_flood should be a size_t */
+    if (!(IsServer(client_p) || IsHandshake(client_p) || IsConnecting(client_p))
+        && (dbuf_length(&client_p->localClient->buf_recvq) >
+            (unsigned int)ConfigFileEntry.client_flood))
+    {
+      if (!(ConfigFileEntry.no_oper_flood && IsOper(client_p)))
+      {
+        exit_client(client_p, client_p, "Excess Flood");
+        return;
+      }
     }
   }
+#ifdef HAVE_LIBCRYPTO
+  while (length == sizeof(readBuf) || fd->ssl);
+#else
+  while (length == sizeof(readBuf));
+#endif
+
+  /* If we get here, we need to register for another COMM_SELECT_READ */
+  comm_setselect(fd, COMM_SELECT_READ, read_packet, client_p, 0);
 }
 
 /*
@@ -492,40 +519,20 @@ read_packet(int fd, void *data)
  *      with client_p of "local" variation, which contains all the
  *      necessary fields (buffer etc..)
  */
-void
+static void
 client_dopacket(struct Client *client_p, char *buffer, size_t length)
 {
-  assert(client_p != NULL);
-  assert(buffer != NULL);
-
-  if(client_p == NULL || buffer == NULL)
-    return;
   /* 
    * Update messages received
    */
-  ++me.localClient->receiveM;
-  ++client_p->localClient->receiveM;
+  ++me.localClient->recv.messages;
+  ++client_p->localClient->recv.messages;
 
   /* 
    * Update bytes received
    */
-  client_p->localClient->receiveB += length;
-
-  if (client_p->localClient->receiveB > 1023)
-  {
-    client_p->localClient->receiveK += (client_p->localClient->receiveB >> 10);
-    client_p->localClient->receiveB &= 0x03ff; /* 2^10 = 1024, 3ff = 1023 */
-  }
-
-  me.localClient->receiveB += length;
-
-  if (me.localClient->receiveB > 1023)
-    {
-      me.localClient->receiveK += (me.localClient->receiveB >> 10);
-      me.localClient->receiveB &= 0x03ff;
-    }
+  client_p->localClient->recv.bytes += length;
+  me.localClient->recv.bytes += length;
 
   parse(client_p, buffer, buffer + length);
 }
-
-
