@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
  *  USA
  *
- *  $Id: restart.c,v 7.23 2003/01/25 05:00:33 lusky Exp $
+ *  $Id: restart.c 588 2006-05-08 13:22:59Z michael $
  */
 
 #include "stdinc.h"
@@ -28,54 +28,69 @@
 #include "common.h"
 #include "fdlist.h"
 #include "ircd.h"
+#include "irc_string.h"
 #include "send.h"
-#include "s_debug.h"
 #include "s_log.h"
-#include "client.h"     /* for FLAGS_ALL */
+#include "client.h" /* for UMODE_ALL */
 #include "memory.h"
 
-
-
-/* external var */
-extern char** myargv;
-
-void restart(char *mesg)
+void
+restart(const char *mesg)
 {
-  static int was_here = NO; /* redundant due to restarting flag below */
+  static int was_here = 0; /* redundant due to restarting flag below */
 
   if (was_here)
     abort();
-  was_here = YES;
+  was_here = 1;
 
-  ilog(L_NOTICE, "Restarting Server because: %s, memory data limit: %ld",
-         mesg, get_maxrss());
-
-  server_reboot();
+  server_die(mesg, YES);
 }
 
-void server_reboot(void)
+void
+server_die(const char *mesg, int rboot)
 {
-  int i;
+  char buffer[IRCD_BUFSIZE];
+  dlink_node *ptr = NULL;
+  struct Client *target_p = NULL;
+  static int was_here = 0;
 
-  sendto_realops_flags(FLAGS_ALL, L_ALL,
-                       "Restarting server...");
+  if (rboot && was_here++)
+    abort();
+
+  if (EmptyString(mesg))
+    snprintf(buffer, sizeof(buffer), "Server %s",
+             rboot ? "Restarting" : "Terminating");
+  else
+    snprintf(buffer, sizeof(buffer), "Server %s: %s",
+             rboot ? "Restarting" : "Terminating", mesg);
+
+  DLINK_FOREACH(ptr, local_client_list.head)
+  {
+    target_p = ptr->data;
+
+    sendto_one(target_p, ":%s NOTICE %s :%s",
+               me.name, target_p->name, buffer);
+  }
+
+  DLINK_FOREACH(ptr, serv_list.head)
+  {
+    target_p = ptr->data;
+
+    sendto_one(target_p, ":%s ERROR :%s", me.name, buffer);
+  }
+
+  ilog(L_NOTICE, buffer);
+
+  send_queued_all();
+  close_fds(NULL);
 
-  ilog(L_NOTICE, "Restarting server... (%s)",SPATH);
-  /*
-   * XXX we used to call flush_connections() here. But since this routine
-   * doesn't exist anymore, we won't be flushing. This is ok, since 
-   * when close handlers come into existance, comm_close() will be called
-   * below, and the data flushing will be implicit.
-   *    -- adrian
-   *
-   * bah, for now, the program ain't coming back to here, so forcibly
-   * close everything the "wrong" way for now, and just LEAVE...
-   */
-  for (i = 3; i < MAXCONNECTIONS; ++i)
-    close(i);
   unlink(pidFileName);
-  execv(SPATH, myargv);
-  fprintf(stderr, "ircd: execv() failed: %s\n", strerror(errno));
-  exit(-1);
-}
 
+  if (rboot)
+  {
+    execv(SPATH, myargv);
+    exit(1);
+  }
+  else
+    exit(0);
+}
